@@ -10,54 +10,54 @@
 
 namespace newsboat {
 
-struct schema_version {
+struct SchemaVersion {
 	unsigned int major, minor;
 
-	friend bool operator<(const schema_version& l, const schema_version& r)
+	friend bool operator<(const SchemaVersion& l, const SchemaVersion& r)
 	{
 		return std::tie(l.major, l.minor) < std::tie(r.major, r.minor);
 	}
-	friend bool operator>(const schema_version& l, const schema_version& r)
+	friend bool operator>(const SchemaVersion& l, const SchemaVersion& r)
 	{
 		return r < l;
 	}
-	friend bool operator<=(const schema_version& l, const schema_version& r)
+	friend bool operator<=(const SchemaVersion& l, const SchemaVersion& r)
 	{
 		return !(l > r);
 	}
-	friend bool operator>=(const schema_version& l, const schema_version& r)
+	friend bool operator>=(const SchemaVersion& l, const SchemaVersion& r)
 	{
 		return !(l < r);
 	}
 };
 
-const schema_version unknown_version = {0, 0};
+const SchemaVersion unknown_version = {0, 0};
 
-using schema_patches = std::map<schema_version, std::vector<std::string>>;
+using schema_patches = std::map<SchemaVersion, std::vector<std::string>>;
 
-class cache {
+class Cache {
 public:
-	cache(const std::string& cachefile, configcontainer* c);
-	~cache();
-	void externalize_rssfeed(std::shared_ptr<rss_feed> feed,
+	Cache(const std::string& cachefile, ConfigContainer* c);
+	~Cache();
+	void externalize_rssfeed(std::shared_ptr<RssFeed> feed,
 		bool reset_unread);
-	std::shared_ptr<rss_feed> internalize_rssfeed(std::string rssurl,
-		rss_ignores* ign);
-	void update_rssitem_unread_and_enqueued(std::shared_ptr<rss_item> item,
+	std::shared_ptr<RssFeed> internalize_rssfeed(std::string rssurl,
+		RssIgnores* ign);
+	void update_rssitem_unread_and_enqueued(std::shared_ptr<RssItem> item,
 		const std::string& feedurl);
-	void update_rssitem_unread_and_enqueued(rss_item* item,
+	void update_rssitem_unread_and_enqueued(RssItem* item,
 		const std::string& feedurl);
-	void cleanup_cache(std::vector<std::shared_ptr<rss_feed>>& feeds);
+	void cleanup_cache(std::vector<std::shared_ptr<RssFeed>>& feeds);
 	void do_vacuum();
-	std::vector<std::shared_ptr<rss_item>> search_for_items(
+	std::vector<std::shared_ptr<RssItem>> search_for_items(
 		const std::string& querystr,
 		const std::string& feedurl);
 	std::unordered_set<std::string> search_in_items(
 		const std::string& querystr,
 		const std::unordered_set<std::string>& guids);
 	void mark_all_read(const std::string& feedurl = "");
-	void mark_all_read(std::shared_ptr<rss_feed> feed);
-	void update_rssitem_flags(rss_item* item);
+	void mark_all_read(std::shared_ptr<RssFeed> feed);
+	void update_rssitem_flags(RssItem* item);
 	void fetch_lastmodified(const std::string& uri,
 		time_t& t,
 		std::string& etag);
@@ -71,15 +71,15 @@ public:
 		const std::vector<std::string>& guids);
 	void mark_items_read_by_guid(const std::vector<std::string>& guids);
 	std::vector<std::string> get_read_item_guids();
-	void fetch_descriptions(rss_feed* feed);
+	void fetch_descriptions(RssFeed* feed);
 
 private:
-	schema_version get_schema_version();
+	SchemaVersion get_schema_version();
 	void populate_tables();
 	void set_pragmas();
-	void delete_item(const std::shared_ptr<rss_item>& item);
+	void delete_item(const std::shared_ptr<RssItem>& item);
 	void clean_old_articles();
-	void update_rssitem_unlocked(std::shared_ptr<rss_item> item,
+	void update_rssitem_unlocked(std::shared_ptr<RssItem> item,
 		const std::string& feedurl,
 		bool reset_unread);
 
@@ -104,7 +104,7 @@ private:
 		bool do_throw);
 
 	sqlite3* db;
-	configcontainer* cfg;
+	ConfigContainer* cfg;
 	std::mutex mtx;
 };
 
