@@ -10,39 +10,41 @@
 #include "feedcontainer.h"
 #include "filtercontainer.h"
 #include "fslock.h"
+#include "opml.h"
+#include "queuemanager.h"
 #include "regexmanager.h"
 #include "reloader.h"
-#include "remote_api.h"
+#include "remoteapi.h"
 #include "rss.h"
 #include "urlreader.h"
 
 namespace newsboat {
 
-class view;
+class View;
 
-class curl_handle;
+class CurlHandle;
 
-class controller {
+class Controller {
 public:
-	controller();
-	~controller();
-	void set_view(view* vv);
-	view* get_view()
+	Controller();
+	~Controller();
+	void set_view(View* vv);
+	View* get_view()
 	{
 		return v;
 	}
-	int run(const CLIArgsParser& args);
+	int run(const CliArgsParser& args);
 
-	std::vector<std::shared_ptr<rss_item>> search_for_items(
+	std::vector<std::shared_ptr<RssItem>> search_for_items(
 		const std::string& query,
-		std::shared_ptr<rss_feed> feed);
+		std::shared_ptr<RssFeed> feed);
 
 	void update_feedlist();
 	void update_visible_feeds();
 	void mark_all_read(unsigned int pos);
 	void mark_article_read(const std::string& guid, bool read);
 	void mark_all_read(const std::string& feedurl);
-	void mark_all_read(std::shared_ptr<rss_feed> feed)
+	void mark_all_read(std::shared_ptr<RssFeed> feed)
 	{
 		rsscache->mark_all_read(feed);
 	}
@@ -50,36 +52,20 @@ public:
 	{
 		return refresh_on_start;
 	}
-	void enqueue_url(const std::string& url,
-		std::shared_ptr<rss_feed> feed);
+	void enqueue_url(std::shared_ptr<RssItem> item, std::shared_ptr<RssFeed> feed);
 
 	void reload_urls_file();
 	void edit_urls_file();
 
-	filtercontainer& get_filters()
-	{
-		return filters;
-	}
-
-	cache* get_cache()
-	{
-		return rsscache;
-	}
-
-	configcontainer* get_cfg()
-	{
-		return &cfg;
-	}
-
 	FeedContainer* get_feedcontainer()
 	{
 		return &feedcontainer;
 	}
 
-	void write_item(std::shared_ptr<rss_item> item,
+	void write_item(std::shared_ptr<RssItem> item,
 		const std::string& filename);
-	void write_item(std::shared_ptr<rss_item> item, std::ostream& ostr);
-	std::string write_temporary_item(std::shared_ptr<rss_item> item);
+	void write_item(std::shared_ptr<RssItem> item, std::ostream& ostr);
+	std::string write_temporary_item(std::shared_ptr<RssItem> item);
 
 	void update_config();
 
@@ -87,24 +73,24 @@ public:
 
 	void dump_config(const std::string& filename);
 
-	void update_flags(std::shared_ptr<rss_item> item);
+	void update_flags(std::shared_ptr<RssItem> item);
 
 	Reloader* get_reloader()
 	{
-		return &reloader;
+		return reloader.get();
 	}
 
-	void replace_feed(std::shared_ptr<rss_feed> oldfeed,
-		std::shared_ptr<rss_feed> newfeed,
+	void replace_feed(std::shared_ptr<RssFeed> oldfeed,
+		std::shared_ptr<RssFeed> newfeed,
 		unsigned int pos,
 		bool unattended);
 
-	rss_ignores* get_ignores()
+	RssIgnores* get_ignores()
 	{
 		return &ign;
 	}
 
-	remote_api* get_api()
+	RemoteApi* get_api()
 	{
 		return api;
 	}
@@ -115,35 +101,31 @@ private:
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
 	int execute_commands(const std::vector<std::string>& cmds);
 
-	void enqueue_items(std::shared_ptr<rss_feed> feed);
-
-	std::string generate_enqueue_filename(const std::string& url,
-		std::shared_ptr<rss_feed> feed);
-	std::string get_hostname_from_url(const std::string& url);
-
 	void import_read_information(const std::string& readinfofile);
 	void export_read_information(const std::string& readinfofile);
 
-	view* v;
-	urlreader* urlcfg;
-	cache* rsscache;
+	View* v;
+	UrlReader* urlcfg;
+	Cache* rsscache;
 	bool refresh_on_start;
-	configcontainer cfg;
-	rss_ignores ign;
+	ConfigContainer cfg;
+	RssIgnores ign;
 	FeedContainer feedcontainer;
-	filtercontainer filters;
+	FilterContainer filters;
 
-	configparser cfgparser;
-	colormanager colorman;
-	regexmanager rxman;
-	remote_api* api;
+	ConfigParser cfgparser;
+	ColorManager colorman;
+	RegexManager rxman;
+	RemoteApi* api;
 	std::mutex feeds_mutex;
 
-	std::unique_ptr<FSLock> fslock;
+	std::unique_ptr<FsLock> fslock;
 
 	ConfigPaths configpaths;
 
-	Reloader reloader;
+	std::unique_ptr<Reloader> reloader;
+
+	QueueManager queueManager;
 };
 
 } // namespace newsboat
