@@ -6,9 +6,9 @@
 
 namespace newsboat {
 
-class fmtstr_formatter {
+class FmtStrFormatter {
 public:
-	fmtstr_formatter() {}
+	FmtStrFormatter() {}
 	void register_fmt(char f, const std::string& value);
 	std::string do_format(const std::string& fmt, unsigned int width = 0);
 	std::wstring do_wformat(const std::wstring& fmt,
