@@ -5,32 +5,32 @@
 
 namespace newsboat {
 
-class matchable {
+class Matchable {
 public:
-	matchable();
-	virtual ~matchable();
+	Matchable();
+	virtual ~Matchable();
 	virtual bool has_attribute(const std::string& attribname) = 0;
 	virtual std::string get_attribute(const std::string& attribname) = 0;
 };
 
-class matcher {
+class Matcher {
 public:
-	matcher();
-	explicit matcher(const std::string& expr);
+	Matcher();
+	explicit Matcher(const std::string& expr);
 	bool parse(const std::string& expr);
-	bool matches(matchable* item);
+	bool matches(Matchable* item);
 	const std::string& get_parse_error();
 	const std::string& get_expression();
 
 private:
-	bool matches_r(expression* e, matchable* item);
+	bool matches_r(expression* e, Matchable* item);
 
-	bool matchop_lt(expression* e, matchable* item);
-	bool matchop_gt(expression* e, matchable* item);
-	bool matchop_rxeq(expression* e, matchable* item);
-	bool matchop_cont(expression* e, matchable* item);
-	bool matchop_eq(expression* e, matchable* item);
-	bool matchop_between(expression* e, matchable* item);
+	bool matchop_lt(expression* e, Matchable* item);
+	bool matchop_gt(expression* e, Matchable* item);
+	bool matchop_rxeq(expression* e, Matchable* item);
+	bool matchop_cont(expression* e, Matchable* item);
+	bool matchop_eq(expression* e, Matchable* item);
+	bool matchop_between(expression* e, Matchable* item);
 
 	FilterParser p;
 	std::string errmsg;
