@@ -4,14 +4,19 @@
 
 #include "config.h"
 #include "exception.h"
-#include "pb_controller.h"
-#include "pb_view.h"
+#include "pbcontroller.h"
+#include "pbview.h"
 #include "utils.h"
 
+extern "C" {
+	void rs_setup_human_panic(void);
+}
+
 using namespace podboat;
 
 int main(int argc, char* argv[])
 {
+	rs_setup_human_panic();
 	utils::initialize_ssl_implementation();
 
 	setlocale(LC_CTYPE, "");
@@ -20,16 +25,16 @@ int main(int argc, char* argv[])
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 
-	pb_controller c;
+	PbController c;
 
 	int ret;
 	try {
-		podboat::pb_view v(&c);
+		podboat::PbView v(&c);
 		c.set_view(&v);
 
 		ret = c.run(argc, argv);
-	} catch (const newsboat::exception& e) {
-		std::cerr << strprintf::fmt(_("Caught newsboat::exception with "
+	} catch (const newsboat::Exception& e) {
+		std::cerr << strprintf::fmt(_("Caught newsboat::Exception with "
 					      "message: %s"),
 				     e.what())
 			  << std::endl;
