@@ -1,13 +1,14 @@
 #include "cliargsparser.h"
 
 #include <getopt.h>
+#include <cstdlib>
 
 #include "globals.h"
 #include "strprintf.h"
 
 namespace newsboat {
 
-CLIArgsParser::CLIArgsParser(int argc, char* argv[])
+CliArgsParser::CliArgsParser(int argc, char* argv[])
 {
 	int c;
 
@@ -35,7 +36,7 @@ CLIArgsParser::CLIArgsParser(int argc, char* argv[])
 	// Ask getopt to re-initialize itself.
 	//
 	// This isn't necessary for real-world use, because we parse arguments
-	// only once; but this is *very* important in tests, where CLIArgsParser
+	// only once; but this is *very* important in tests, where CliArgsParser
 	// is ran dozens of times.
 	//
 	// Note we use 0, not 1. getopt(3) says that the value of 0 forces
@@ -135,8 +136,8 @@ CLIArgsParser::CLIArgsParser(int argc, char* argv[])
 			log_file = optarg;
 			break;
 		case 'l': {
-			level l = static_cast<level>(atoi(optarg));
-			if (l > level::NONE && l <= level::DEBUG) {
+			Level l = static_cast<Level>(atoi(optarg));
+			if (l > Level::NONE && l <= Level::DEBUG) {
 				set_log_level = true;
 				log_level = l;
 			} else {
@@ -144,7 +145,7 @@ CLIArgsParser::CLIArgsParser(int argc, char* argv[])
 					strprintf::fmt(_("%s: %d: invalid "
 							 "loglevel value"),
 						argv[0],
-						l);
+						static_cast<int>(l));
 
 				should_return = true;
 				return_code = EXIT_FAILURE;
