@@ -1,8 +1,10 @@
 #include "configpaths.h"
 
 #include <cstring>
+#include <fstream>
 #include <iostream>
 #include <pwd.h>
+#include <string>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -129,7 +131,7 @@ bool ConfigPaths::find_dirs_xdg()
 	return true;
 }
 
-void ConfigPaths::process_args(const CLIArgsParser& args)
+void ConfigPaths::process_args(const CliArgsParser& args)
 {
 	if (args.set_url_file) {
 		m_url_file = args.url_file;
@@ -216,7 +218,7 @@ bool ConfigPaths::migrate_data_from_newsbeuter_xdg()
 	auto exists = [](const std::string& dir) -> bool {
 		bool dir_exists = 0 == access(dir.c_str(), F_OK);
 		if (dir_exists) {
-			LOG(level::DEBUG,
+			LOG(Level::DEBUG,
 				"%s already exists, aborting XDG migration.",
 				dir);
 		}
@@ -242,7 +244,7 @@ bool ConfigPaths::migrate_data_from_newsbeuter_xdg()
 		// If dir already exists, it's an error, so we won't check the
 		// errno (unlike in many other places in the code)
 		if (!result) {
-			LOG(level::DEBUG,
+			LOG(Level::DEBUG,
 				"Aborting XDG migration because mkdir on %s "
 				"failed: %s",
 				dir,
@@ -294,7 +296,7 @@ bool ConfigPaths::migrate_data_from_newsbeuter_simple()
 
 	bool newsboat_dir_exists = 0 == access(newsboat_dir.c_str(), F_OK);
 	if (newsboat_dir_exists) {
-		LOG(level::DEBUG,
+		LOG(Level::DEBUG,
 			"%s already exists, aborting migration.",
 			newsboat_dir);
 		return false;
@@ -355,7 +357,7 @@ bool ConfigPaths::create_dirs() const
 	auto try_mkdir = [](const std::string& dir) -> bool {
 		const bool result = 0 == utils::mkdir_parents(dir, 0700);
 		if (!result && errno != EEXIST) {
-			LOG(level::CRITICAL,
+			LOG(Level::CRITICAL,
 				"Couldn't create `%s': (%i) %s",
 				dir,
 				errno,
