@@ -3,7 +3,6 @@
 #include <cassert>
 #include <cerrno>
 #include <cstdlib>
-#include <cstring>
 #include <ctime>
 #include <curl/curl.h>
 #include <fstream>
@@ -13,7 +12,6 @@
 #include <libgen.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
-#include <libxml/uri.h>
 #include <libxml/xmlsave.h>
 #include <libxml/xmlversion.h>
 #include <mutex>
@@ -33,20 +31,22 @@
 #include "downloadthread.h"
 #include "exception.h"
 #include "exceptions.h"
-#include "feedhq_api.h"
-#include "formatstring.h"
+#include "feedhqapi.h"
+#include "fileurlreader.h"
 #include "globals.h"
-#include "inoreader_api.h"
+#include "inoreaderapi.h"
+#include "itemrenderer.h"
 #include "logger.h"
-#include "newsblur_api.h"
-#include "ocnews_api.h"
-#include "oldreader_api.h"
+#include "newsblurapi.h"
+#include "ocnewsapi.h"
+#include "oldreaderapi.h"
+#include "opmlurlreader.h"
 #include "regexmanager.h"
-#include "remote_api.h"
-#include "rss_parser.h"
+#include "remoteapi.h"
+#include "rssparser.h"
 #include "stflpp.h"
 #include "strprintf.h"
-#include "ttrss_api.h"
+#include "ttrssapi.h"
 #include "utils.h"
 #include "view.h"
 
@@ -54,36 +54,27 @@ namespace newsboat {
 
 void sighup_action(int /* sig */)
 {
-	LOG(level::DEBUG, "caught SIGHUP");
-	stfl::reset();
+	LOG(Level::DEBUG, "caught SIGHUP");
+	Stfl::reset();
 	::exit(EXIT_FAILURE);
 }
 
 void ignore_signal(int sig)
 {
-	LOG(level::WARN, "caught signal %d but ignored it", sig);
+	LOG(Level::WARN, "caught signal %d but ignored it", sig);
 }
 
-void omg_a_child_died(int /* sig */)
-{
-	pid_t pid;
-	int stat;
-	while ((pid = waitpid(-1, &stat, WNOHANG)) > 0) {
-	}
-	::signal(SIGCHLD, omg_a_child_died); /* in case of unreliable signals */
-}
-
-controller::controller()
+Controller::Controller()
 	: v(0)
 	, urlcfg(0)
 	, rsscache(0)
 	, refresh_on_start(false)
 	, api(0)
-	, reloader(this)
+	, queueManager(&cfg, &configpaths)
 {
 }
 
-controller::~controller()
+Controller::~Controller()
 {
 	delete rsscache;
 	delete urlcfg;
@@ -93,17 +84,16 @@ controller::~controller()
 	feedcontainer.feeds.clear();
 }
 
-void controller::set_view(view* vv)
+void Controller::set_view(View* vv)
 {
 	v = vv;
 }
 
-int controller::run(const CLIArgsParser& args)
+int Controller::run(const CliArgsParser& args)
 {
-	::signal(SIGINT, view::ctrl_c_action);
+	::signal(SIGINT, View::ctrl_c_action);
 	::signal(SIGPIPE, ignore_signal);
 	::signal(SIGHUP, sighup_action);
-	::signal(SIGCHLD, omg_a_child_died);
 
 	if (!configpaths.initialized()) {
 		std::cerr << configpaths.error_message() << std::endl;
@@ -113,11 +103,11 @@ int controller::run(const CLIArgsParser& args)
 	refresh_on_start = args.refresh_on_start;
 
 	if (args.set_log_file) {
-		logger::getInstance().set_logfile(args.log_file);
+		Logger::set_logfile(args.log_file);
 	}
 
 	if (args.set_log_level) {
-		logger::getInstance().set_loglevel(args.log_level);
+		Logger::set_loglevel(args.log_level);
 	}
 
 	if (!args.display_msg.empty()) {
@@ -131,16 +121,16 @@ int controller::run(const CLIArgsParser& args)
 	configpaths.process_args(args);
 
 	if (args.do_import) {
-		LOG(level::INFO,
+		LOG(Level::INFO,
 			"Importing OPML file from %s",
 			args.importfile);
-		urlcfg = new file_urlreader(configpaths.url_file());
+		urlcfg = new FileUrlReader(configpaths.url_file());
 		urlcfg->reload();
 		import_opml(args.importfile);
 		return EXIT_SUCCESS;
 	}
 
-	LOG(level::INFO, "nl_langinfo(CODESET): %s", nl_langinfo(CODESET));
+	LOG(Level::INFO, "nl_langinfo(CODESET): %s", nl_langinfo(CODESET));
 
 	if (!configpaths.setup_dirs()) {
 		return EXIT_FAILURE;
@@ -153,7 +143,7 @@ int controller::run(const CLIArgsParser& args)
 					     PROGRAM_VERSION)
 				  << std::endl;
 
-		fslock = std::unique_ptr<FSLock>(new FSLock());
+		fslock = std::unique_ptr<FsLock>(new FsLock());
 		pid_t pid;
 		if (!fslock->try_lock(configpaths.lock_file(), pid)) {
 			if (!args.execute_cmds) {
@@ -176,7 +166,7 @@ int controller::run(const CLIArgsParser& args)
 	cfg.register_commands(cfgparser);
 	colorman.register_commands(cfgparser);
 
-	keymap keys(KM_NEWSBOAT);
+	KeyMap keys(KM_NEWSBOAT);
 	cfgparser.register_handler("bind-key", &keys);
 	cfgparser.register_handler("unbind-key", &keys);
 	cfgparser.register_handler("macro", &keys);
@@ -192,8 +182,8 @@ int controller::run(const CLIArgsParser& args)
 	try {
 		cfgparser.parse("/etc/" PROGRAM_NAME "/config");
 		cfgparser.parse(configpaths.config_file());
-	} catch (const configexception& ex) {
-		LOG(level::ERROR,
+	} catch (const ConfigException& ex) {
+		LOG(Level::ERROR,
 			"an exception occurred while parsing the configuration "
 			"file: %s",
 			ex.what());
@@ -210,7 +200,7 @@ int controller::run(const CLIArgsParser& args)
 	std::string cachefilepath = cfg.get_configvalue("cache-file");
 	if (cachefilepath.length() > 0 && !args.set_cache_file) {
 		configpaths.set_cache_file(cachefilepath);
-		fslock = std::unique_ptr<FSLock>(new FSLock());
+		fslock = std::unique_ptr<FsLock>(new FsLock());
 		pid_t pid;
 		if (!fslock->try_lock(configpaths.lock_file(), pid)) {
 			std::cout << strprintf::fmt(
@@ -228,8 +218,8 @@ int controller::run(const CLIArgsParser& args)
 		std::cout.flush();
 	}
 	try {
-		rsscache = new cache(configpaths.cache_file(), &cfg);
-	} catch (const dbexception& e) {
+		rsscache = new Cache(configpaths.cache_file(), &cfg);
+	} catch (const DbException& e) {
 		std::cerr << strprintf::fmt(
 				     _("Error: opening the cache file `%s' "
 				       "failed: %s"),
@@ -251,24 +241,27 @@ int controller::run(const CLIArgsParser& args)
 		std::cout << _("done.") << std::endl;
 	}
 
+	reloader =
+		std::unique_ptr<Reloader>(new Reloader(this, rsscache, &cfg));
+
 	std::string type = cfg.get_configvalue("urls-source");
 	if (type == "local") {
-		urlcfg = new file_urlreader(configpaths.url_file());
+		urlcfg = new FileUrlReader(configpaths.url_file());
 	} else if (type == "opml") {
-		urlcfg = new opml_urlreader(&cfg);
+		urlcfg = new OpmlUrlReader(&cfg);
 	} else if (type == "oldreader") {
-		api = new oldreader_api(&cfg);
-		urlcfg = new oldreader_urlreader(
+		api = new OldReaderApi(&cfg);
+		urlcfg = new OldReaderUrlReader(
 			&cfg, configpaths.url_file(), api);
 	} else if (type == "ttrss") {
-		api = new ttrss_api(&cfg);
-		urlcfg = new ttrss_urlreader(configpaths.url_file(), api);
+		api = new TtRssApi(&cfg);
+		urlcfg = new TtRssUrlReader(configpaths.url_file(), api);
 	} else if (type == "newsblur") {
 		const auto cookies = cfg.get_configvalue("cookie-cache");
 		if (cookies.empty()) {
 			std::cout << strprintf::fmt(
 				_("ERROR: You must set `cookie-cache` to use "
-				  "Newsblur.\n"));
+				  "NewsBlur.\n"));
 			return EXIT_FAILURE;
 		}
 
@@ -280,21 +273,20 @@ int controller::run(const CLIArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new newsblur_api(&cfg);
-		urlcfg = new newsblur_urlreader(configpaths.url_file(), api);
+		api = new NewsBlurApi(&cfg);
+		urlcfg = new NewsBlurUrlReader(configpaths.url_file(), api);
 	} else if (type == "feedhq") {
-		api = new feedhq_api(&cfg);
-		urlcfg =
-			new feedhq_urlreader(&cfg, configpaths.url_file(), api);
+		api = new FeedHqApi(&cfg);
+		urlcfg = new FeedHqUrlReader(&cfg, configpaths.url_file(), api);
 	} else if (type == "ocnews") {
-		api = new ocnews_api(&cfg);
-		urlcfg = new ocnews_urlreader(configpaths.url_file(), api);
+		api = new OcNewsApi(&cfg);
+		urlcfg = new OcNewsUrlReader(configpaths.url_file(), api);
 	} else if (type == "inoreader") {
-		api = new inoreader_api(&cfg);
-		urlcfg = new inoreader_urlreader(
+		api = new InoreaderApi(&cfg);
+		urlcfg = new InoreaderUrlReader(
 			&cfg, configpaths.url_file(), api);
 	} else {
-		LOG(level::ERROR,
+		LOG(Level::ERROR,
 			"unknown urls-source `%s'",
 			urlcfg->get_source());
 	}
@@ -316,7 +308,7 @@ int controller::run(const CLIArgsParser& args)
 	}
 
 	if (urlcfg->get_urls().size() == 0) {
-		LOG(level::ERROR, "no URLs configured.");
+		LOG(Level::ERROR, "no URLs configured.");
 		std::string msg;
 		if (type == "local") {
 			msg = strprintf::fmt(
@@ -377,13 +369,13 @@ int controller::run(const CLIArgsParser& args)
 			bool ignore_disp =
 				(cfg.get_configvalue("ignore-mode") ==
 					"display");
-			std::shared_ptr<rss_feed> feed =
+			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
 					url, ignore_disp ? &ign : nullptr);
 			feed->set_tags(urlcfg->get_tags(url));
 			feed->set_order(i);
 			feedcontainer.add_feed(feed);
-		} catch (const dbexception& e) {
+		} catch (const DbException& e) {
 			std::cout << _("Error while loading feeds from "
 				       "database: ")
 				  << e.what() << std::endl;
@@ -428,7 +420,7 @@ int controller::run(const CLIArgsParser& args)
 	}
 
 	if (args.do_read_import) {
-		LOG(level::INFO,
+		LOG(Level::INFO,
 			"Importing read information file from %s",
 			args.readinfofile);
 		std::cout << _("Importing list of read articles...");
@@ -439,7 +431,7 @@ int controller::run(const CLIArgsParser& args)
 	}
 
 	if (args.do_read_export) {
-		LOG(level::INFO,
+		LOG(Level::INFO,
 			"Exporting read information file to %s",
 			args.readinfofile);
 		std::cout << _("Exporting list of read articles...");
@@ -449,10 +441,12 @@ int controller::run(const CLIArgsParser& args)
 		return EXIT_SUCCESS;
 	}
 
-	// hand over the important objects to the view
+	// hand over the important objects to the View
 	v->set_config_container(&cfg);
 	v->set_keymap(&keys);
 	v->set_tags(tags);
+	v->set_cache(rsscache);
+	v->set_filters(&filters);
 
 	if (args.execute_cmds) {
 		execute_commands(args.cmds_to_execute);
@@ -466,16 +460,16 @@ int controller::run(const CLIArgsParser& args)
 		refresh_on_start = true;
 	}
 
-	formaction::load_histories(
+	FormAction::load_histories(
 		configpaths.search_file(), configpaths.cmdline_file());
 
-	// run the view
+	// run the View
 	int ret = v->run();
 
 	unsigned int history_limit =
 		cfg.get_configvalue_as_int("history-limit");
-	LOG(level::DEBUG, "controller::run: history-limit = %u", history_limit);
-	formaction::save_histories(configpaths.search_file(),
+	LOG(Level::DEBUG, "Controller::run: history-limit = %u", history_limit);
+	FormAction::save_histories(configpaths.search_file(),
 		configpaths.cmdline_file(),
 		history_limit);
 
@@ -489,8 +483,8 @@ int controller::run(const CLIArgsParser& args)
 		if (!args.silent) {
 			std::cout << _("done.") << std::endl;
 		}
-	} catch (const dbexception& e) {
-		LOG(level::USERERROR, "Cleaning up cache failed: %s", e.what());
+	} catch (const DbException& e) {
+		LOG(Level::USERERROR, "Cleaning up cache failed: %s", e.what());
 		if (!args.silent) {
 			std::cout << _("failed: ") << e.what() << std::endl;
 			ret = EXIT_FAILURE;
@@ -500,23 +494,23 @@ int controller::run(const CLIArgsParser& args)
 	return ret;
 }
 
-void controller::update_feedlist()
+void Controller::update_feedlist()
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	v->set_feedlist(feedcontainer.feeds);
 }
 
-void controller::update_visible_feeds()
+void Controller::update_visible_feeds()
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	v->update_visible_feeds(feedcontainer.feeds);
 }
 
-void controller::mark_all_read(const std::string& feedurl)
+void Controller::mark_all_read(const std::string& feedurl)
 {
 	try {
 		rsscache->mark_all_read(feedurl);
-	} catch (const dbexception& e) {
+	} catch (const DbException& e) {
 		v->show_error(strprintf::fmt(
 			_("Error: couldn't mark all feeds read: %s"),
 			e.what()));
@@ -546,17 +540,17 @@ void controller::mark_all_read(const std::string& feedurl)
 	}
 }
 
-void controller::mark_article_read(const std::string& guid, bool read)
+void Controller::mark_article_read(const std::string& guid, bool read)
 {
 	if (api) {
 		api->mark_article_read(guid, read);
 	}
 }
 
-void controller::mark_all_read(unsigned int pos)
+void Controller::mark_all_read(unsigned int pos)
 {
 	if (pos < feedcontainer.feeds.size()) {
-		scope_measure m("controller::mark_all_read");
+		ScopeMeasure m("Controller::mark_all_read");
 		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		const auto feed = feedcontainer.get_feed(pos);
 		if (feed->is_query_feed()) {
@@ -575,29 +569,32 @@ void controller::mark_all_read(unsigned int pos)
 	}
 }
 
-void controller::replace_feed(std::shared_ptr<rss_feed> oldfeed,
-	std::shared_ptr<rss_feed> newfeed,
+void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
+	std::shared_ptr<RssFeed> newfeed,
 	unsigned int pos,
 	bool unattended)
 {
 	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 
-	LOG(level::DEBUG, "controller::replace_feed: feed is nonempty, saving");
+	LOG(Level::DEBUG, "Controller::replace_feed: feed is nonempty, saving");
 	rsscache->externalize_rssfeed(
 		newfeed, ign.matches_resetunread(newfeed->rssurl()));
-	LOG(level::DEBUG,
-		"controller::replace_feed: after externalize_rssfeed");
+	LOG(Level::DEBUG,
+		"Controller::replace_feed: after externalize_rssfeed");
 
 	bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
-	std::shared_ptr<rss_feed> feed = rsscache->internalize_rssfeed(
+	std::shared_ptr<RssFeed> feed = rsscache->internalize_rssfeed(
 		oldfeed->rssurl(), ignore_disp ? &ign : nullptr);
-	LOG(level::DEBUG,
-		"controller::replace_feed: after internalize_rssfeed");
+	LOG(Level::DEBUG,
+		"Controller::replace_feed: after internalize_rssfeed");
 
 	feed->set_tags(urlcfg->get_tags(oldfeed->rssurl()));
 	feed->set_order(oldfeed->get_order());
 	feedcontainer.feeds[pos] = feed;
-	enqueue_items(feed);
+	queueManager.autoenqueue(feed);
+	for (const auto& item : feed->items()) {
+		rsscache->update_rssitem_unread_and_enqueued(item, feed->rssurl());
+	}
 
 	oldfeed->clear_items();
 
@@ -607,206 +604,37 @@ void controller::replace_feed(std::shared_ptr<rss_feed> oldfeed,
 	}
 }
 
-void controller::import_opml(const std::string& filename)
+void Controller::import_opml(const std::string& filename)
 {
-	xmlDoc* doc = xmlReadFile(filename.c_str(), nullptr, 0);
-	if (doc == nullptr) {
+	if (!opml::import(filename, urlcfg)) {
 		std::cout << strprintf::fmt(
 				     _("An error occurred while parsing %s."),
 				     filename)
 			  << std::endl;
 		return;
+	} else {
+		std::cout << strprintf::fmt(
+				     _("Import of %s finished."), filename)
+			  << std::endl;
 	}
-
-	xmlNode* root = xmlDocGetRootElement(doc);
-
-	for (xmlNode* node = root->children; node != nullptr;
-		node = node->next) {
-		if (strcmp((const char*)node->name, "body") == 0) {
-			LOG(level::DEBUG, "import_opml: found body");
-			rec_find_rss_outlines(node->children, "");
-			urlcfg->write_config();
-		}
-	}
-
-	xmlFreeDoc(doc);
-	std::cout << strprintf::fmt(_("Import of %s finished."), filename)
-		  << std::endl;
 }
 
-void controller::export_opml()
+void Controller::export_opml()
 {
-	xmlDocPtr root = xmlNewDoc((const xmlChar*)"1.0");
-	xmlNodePtr opml_node =
-		xmlNewDocNode(root, nullptr, (const xmlChar*)"opml", nullptr);
-	xmlSetProp(opml_node, (const xmlChar*)"version", (const xmlChar*)"1.0");
-	xmlDocSetRootElement(root, opml_node);
-
-	xmlNodePtr head = xmlNewTextChild(
-		opml_node, nullptr, (const xmlChar*)"head", nullptr);
-	xmlNewTextChild(head,
-		nullptr,
-		(const xmlChar*)"title",
-		(const xmlChar*)PROGRAM_NAME " - Exported Feeds");
-	xmlNodePtr body = xmlNewTextChild(
-		opml_node, nullptr, (const xmlChar*)"body", nullptr);
-
-	for (const auto& feed : feedcontainer.feeds) {
-		if (!utils::is_special_url(feed->rssurl())) {
-			std::string rssurl = feed->rssurl();
-			std::string link = feed->link();
-			std::string title = feed->title();
-
-			xmlNodePtr outline = xmlNewTextChild(body,
-				nullptr,
-				(const xmlChar*)"outline",
-				nullptr);
-			xmlSetProp(outline,
-				(const xmlChar*)"type",
-				(const xmlChar*)"rss");
-			xmlSetProp(outline,
-				(const xmlChar*)"xmlUrl",
-				(const xmlChar*)rssurl.c_str());
-			xmlSetProp(outline,
-				(const xmlChar*)"htmlUrl",
-				(const xmlChar*)link.c_str());
-			xmlSetProp(outline,
-				(const xmlChar*)"title",
-				(const xmlChar*)title.c_str());
-		}
-	}
+	xmlDocPtr root = opml::generate(feedcontainer);
 
 	xmlSaveCtxtPtr savectx = xmlSaveToFd(1, nullptr, 1);
 	xmlSaveDoc(savectx, root);
 	xmlSaveClose(savectx);
 
-	xmlFreeNode(opml_node);
+	xmlFreeDoc(root);
 }
 
-void controller::rec_find_rss_outlines(xmlNode* node, std::string tag)
-{
-	while (node) {
-		std::string newtag = tag;
-
-		if (strcmp((const char*)node->name, "outline") == 0) {
-			char* url = (char*)xmlGetProp(
-				node, (const xmlChar*)"xmlUrl");
-			if (!url) {
-				url = (char*)xmlGetProp(
-					node, (const xmlChar*)"url");
-			}
-
-			if (url) {
-				LOG(level::DEBUG,
-					"OPML import: found RSS outline with "
-					"url = "
-					"%s",
-					url);
-
-				std::string nurl = std::string(url);
-
-				// Liferea uses a pipe to signal feeds read from
-				// the output of a program in its OPMLs. Convert
-				// them to our syntax.
-				if (*url == '|') {
-					nurl = strprintf::fmt(
-						"exec:%s", url + 1);
-					LOG(level::DEBUG,
-						"OPML import: liferea-style "
-						"url %s "
-						"converted to %s",
-						url,
-						nurl);
-				}
-
-				// Handle OPML filters.
-				char* filtercmd = (char*)xmlGetProp(
-					node, (const xmlChar*)"filtercmd");
-				if (filtercmd) {
-					LOG(level::DEBUG,
-						"OPML import: adding filter "
-						"command %s to url %s",
-						filtercmd,
-						nurl);
-					nurl.insert(0,
-						strprintf::fmt("filter:%s:",
-							filtercmd));
-					xmlFree(filtercmd);
-				}
-
-				xmlFree(url);
-				// Filters and scripts may have arguments, so,
-				// quote them when needed.
-				url = (char*)xmlStrdup(
-					(const xmlChar*)
-						utils::quote_if_necessary(nurl)
-							.c_str());
-				assert(url);
-
-				bool found = false;
-
-				LOG(level::DEBUG,
-					"OPML import: size = %u",
-					urlcfg->get_urls().size());
-				if (urlcfg->get_urls().size() > 0) {
-					for (const auto& u :
-						urlcfg->get_urls()) {
-						if (u == url) {
-							found = true;
-						}
-					}
-				}
-
-				if (!found) {
-					LOG(level::DEBUG,
-						"OPML import: added url = %s",
-						url);
-					urlcfg->get_urls().push_back(
-						std::string(url));
-					if (tag.length() > 0) {
-						LOG(level::DEBUG,
-							"OPML import: "
-							"appending "
-							"tag %s to url %s",
-							tag,
-							url);
-						urlcfg->get_tags(url).push_back(
-							tag);
-					}
-				} else {
-					LOG(level::DEBUG,
-						"OPML import: url = %s is "
-						"already "
-						"in list",
-						url);
-				}
-				xmlFree(url);
-			} else {
-				char* text = (char*)xmlGetProp(
-					node, (const xmlChar*)"text");
-				if (!text)
-					text = (char*)xmlGetProp(
-						node, (const xmlChar*)"title");
-				if (text) {
-					if (newtag.length() > 0) {
-						newtag.append("/");
-					}
-					newtag.append(text);
-					xmlFree(text);
-				}
-			}
-		}
-		rec_find_rss_outlines(node->children, newtag);
-
-		node = node->next;
-	}
-}
-
-std::vector<std::shared_ptr<rss_item>> controller::search_for_items(
+std::vector<std::shared_ptr<RssItem>> Controller::search_for_items(
 	const std::string& query,
-	std::shared_ptr<rss_feed> feed)
+	std::shared_ptr<RssFeed> feed)
 {
-	std::vector<std::shared_ptr<rss_item>> items;
+	std::vector<std::shared_ptr<RssItem>> items;
 	if (feed && feed->is_query_feed()) {
 		std::unordered_set<std::string> guids;
 		for (const auto& item : feed->items()) {
@@ -831,40 +659,16 @@ std::vector<std::shared_ptr<rss_item>> controller::search_for_items(
 	return items;
 }
 
-void controller::enqueue_url(const std::string& url,
-	std::shared_ptr<rss_feed> feed)
+void Controller::enqueue_url(std::shared_ptr<RssItem> item,
+	std::shared_ptr<RssFeed> feed)
 {
-	bool url_found = false;
-	std::fstream f;
-	f.open(configpaths.queue_file().c_str(), std::fstream::in);
-	if (f.is_open()) {
-		do {
-			std::string line;
-			getline(f, line);
-			if (!f.eof() && line.length() > 0) {
-				std::vector<std::string> fields =
-					utils::tokenize_quoted(line);
-				if (!fields.empty() && fields[0] == url) {
-					url_found = true;
-					break;
-				}
-			}
-		} while (!f.eof());
-		f.close();
-	}
-	if (!url_found) {
-		f.open(configpaths.queue_file().c_str(),
-			std::fstream::app | std::fstream::out);
-		std::string filename = generate_enqueue_filename(url, feed);
-		f << url << " " << stfl::quote(filename) << std::endl;
-		f.close();
-	}
+	queueManager.enqueue_url(item, feed);
 }
 
-void controller::reload_urls_file()
+void Controller::reload_urls_file()
 {
 	urlcfg->reload();
-	std::vector<std::shared_ptr<rss_feed>> new_feeds;
+	std::vector<std::shared_ptr<RssFeed>> new_feeds;
 	unsigned int i = 0;
 
 	for (const auto& url : urlcfg->get_urls()) {
@@ -878,15 +682,15 @@ void controller::reload_urls_file()
 				bool ignore_disp =
 					(cfg.get_configvalue("ignore-mode") ==
 						"display");
-				std::shared_ptr<rss_feed> new_feed =
+				std::shared_ptr<RssFeed> new_feed =
 					rsscache->internalize_rssfeed(url,
 						ignore_disp ? &ign : nullptr);
 				new_feed->set_tags(urlcfg->get_tags(url));
 				new_feed->set_order(i);
 				new_feeds.push_back(new_feed);
-			} catch (const dbexception& e) {
-				LOG(level::ERROR,
-					"controller::reload_urls_file: caught "
+			} catch (const DbException& e) {
+				LOG(Level::ERROR,
+					"Controller::reload_urls_file: caught "
 					"exception: %s",
 					e.what());
 				throw;
@@ -902,7 +706,7 @@ void controller::reload_urls_file()
 	update_feedlist();
 }
 
-void controller::edit_urls_file()
+void Controller::edit_urls_file()
 {
 	const char* editor;
 
@@ -917,25 +721,25 @@ void controller::edit_urls_file()
 		utils::replace_all(configpaths.url_file(), "\"", "\\\""));
 
 	v->push_empty_formaction();
-	stfl::reset();
+	Stfl::reset();
 
-	utils::run_interactively(cmdline, "controller::edit_urls_file");
+	utils::run_interactively(cmdline, "Controller::edit_urls_file");
 
 	v->pop_current_formaction();
 
 	reload_urls_file();
 }
 
-int controller::execute_commands(const std::vector<std::string>& cmds)
+int Controller::execute_commands(const std::vector<std::string>& cmds)
 {
 	if (v->formaction_stack_size() > 0)
 		v->pop_current_formaction();
 	for (const auto& cmd : cmds) {
-		LOG(level::DEBUG,
-			"controller::execute_commands: executing `%s'",
+		LOG(Level::DEBUG,
+			"Controller::execute_commands: executing `%s'",
 			cmd);
 		if (cmd == "reload") {
-			reloader.reload_all(true);
+			reloader->reload_all(true);
 		} else if (cmd == "print-unread") {
 			std::cout << strprintf::fmt(_("%u unread articles"),
 					     rsscache->get_unread_count())
@@ -952,14 +756,19 @@ int controller::execute_commands(const std::vector<std::string>& cmds)
 	return EXIT_SUCCESS;
 }
 
-std::string controller::write_temporary_item(std::shared_ptr<rss_item> item)
+std::string Controller::write_temporary_item(std::shared_ptr<RssItem> item)
 {
 	char filename[_POSIX_PATH_MAX];
-	char *tmpdir = getenv("TMPDIR");
+	char* tmpdir = getenv("TMPDIR");
 	if (tmpdir != nullptr) {
-	  snprintf(filename, sizeof(filename), "%s/newsboat-article.XXXXXX", tmpdir);
+		snprintf(filename,
+			sizeof(filename),
+			"%s/newsboat-article.XXXXXX",
+			tmpdir);
 	} else {
-	  snprintf(filename, sizeof(filename), "/tmp/newsboat-article.XXXXXX");
+		snprintf(filename,
+			sizeof(filename),
+			"/tmp/newsboat-article.XXXXXX");
 	}
 	int fd = mkstemp(filename);
 	if (fd != -1) {
@@ -971,127 +780,24 @@ std::string controller::write_temporary_item(std::shared_ptr<rss_item> item)
 	}
 }
 
-void controller::write_item(std::shared_ptr<rss_item> item,
+void Controller::write_item(std::shared_ptr<RssItem> item,
 	const std::string& filename)
 {
 	std::fstream f;
 	f.open(filename.c_str(), std::fstream::out);
 	if (!f.is_open()) {
-		throw exception(errno);
+		throw Exception(errno);
 	}
 
 	write_item(item, f);
 }
 
-void controller::write_item(std::shared_ptr<rss_item> item, std::ostream& ostr)
+void Controller::write_item(std::shared_ptr<RssItem> item, std::ostream& ostr)
 {
-	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links; // not used
-
-	std::string title(_("Title: "));
-	title.append(item->title());
-	lines.push_back(std::make_pair(LineType::wrappable, title));
-
-	std::string author(_("Author: "));
-	author.append(item->author());
-	lines.push_back(std::make_pair(LineType::wrappable, author));
-
-	std::string date(_("Date: "));
-	date.append(item->pubDate());
-	lines.push_back(std::make_pair(LineType::wrappable, date));
-
-	std::string link(_("Link: "));
-	link.append(item->link());
-	lines.push_back(std::make_pair(LineType::softwrappable, link));
-
-	if (item->enclosure_url() != "") {
-		std::string dlurl(_("Podcast Download URL: "));
-		dlurl.append(item->enclosure_url());
-		lines.push_back(std::make_pair(LineType::softwrappable, dlurl));
-	}
-
-	lines.push_back(std::make_pair(LineType::wrappable, std::string("")));
-
-	htmlrenderer rnd(true);
-	rnd.render(item->description(), lines, links, item->feedurl());
-	textformatter txtfmt;
-	txtfmt.add_lines(lines);
-
-	unsigned int width = cfg.get_configvalue_as_int("text-width");
-	if (width == 0)
-		width = 80;
-	ostr << txtfmt.format_text_plain(width) << std::endl;
+	ostr << item_renderer::to_plain_text(cfg, item) << std::endl;
 }
 
-void controller::enqueue_items(std::shared_ptr<rss_feed> feed)
-{
-	if (!cfg.get_configvalue_as_bool("podcast-auto-enqueue"))
-		return;
-	std::lock_guard<std::mutex> lock(feed->item_mutex);
-	for (const auto& item : feed->items()) {
-		if (!item->enqueued() && item->enclosure_url().length() > 0) {
-			LOG(level::DEBUG,
-				"controller::enqueue_items: enclosure_url = "
-				"`%s' "
-				"enclosure_type = `%s'",
-				item->enclosure_url(),
-				item->enclosure_type());
-			if (utils::is_http_url(item->enclosure_url())) {
-				LOG(level::INFO,
-					"controller::enqueue_items: enqueuing "
-					"`%s'",
-					item->enclosure_url());
-				enqueue_url(item->enclosure_url(), feed);
-				item->set_enqueued(true);
-				rsscache->update_rssitem_unread_and_enqueued(
-					item, feed->rssurl());
-			}
-		}
-	}
-}
-
-std::string controller::generate_enqueue_filename(const std::string& url,
-	std::shared_ptr<rss_feed> feed)
-{
-	std::string dlformat = cfg.get_configvalue("download-path");
-	if (dlformat[dlformat.length() - 1] != NEWSBEUTER_PATH_SEP[0])
-		dlformat.append(NEWSBEUTER_PATH_SEP);
-
-	fmtstr_formatter fmt;
-	fmt.register_fmt('n', feed->title());
-	fmt.register_fmt('h', get_hostname_from_url(url));
-
-	std::string dlpath = fmt.do_format(dlformat);
-
-	char buf[2048];
-	snprintf(buf, sizeof(buf), "%s", url.c_str());
-	char* base = basename(buf);
-	if (!base || strlen(base) == 0) {
-		char lbuf[128];
-		time_t t = time(nullptr);
-		strftime(lbuf,
-			sizeof(lbuf),
-			"%Y-%b-%d-%H%M%S.unknown",
-			localtime(&t));
-		dlpath.append(lbuf);
-	} else {
-		dlpath.append(base);
-	}
-	return dlpath;
-}
-
-std::string controller::get_hostname_from_url(const std::string& url)
-{
-	xmlURIPtr uri = xmlParseURI(url.c_str());
-	std::string hostname;
-	if (uri) {
-		hostname = uri->server;
-		xmlFreeURI(uri);
-	}
-	return hostname;
-}
-
-void controller::import_read_information(const std::string& readinfofile)
+void Controller::import_read_information(const std::string& readinfofile)
 {
 	std::vector<std::string> guids;
 
@@ -1108,7 +814,7 @@ void controller::import_read_information(const std::string& readinfofile)
 	rsscache->mark_items_read_by_guid(guids);
 }
 
-void controller::export_read_information(const std::string& readinfofile)
+void Controller::export_read_information(const std::string& readinfofile)
 {
 	std::vector<std::string> guids = rsscache->get_read_item_guids();
 
@@ -1121,7 +827,7 @@ void controller::export_read_information(const std::string& readinfofile)
 	}
 }
 
-void controller::update_config()
+void Controller::update_config()
 {
 	v->set_regexmanager(&rxman);
 	v->update_bindings();
@@ -1135,9 +841,8 @@ void controller::update_config()
 
 	if (cfg.get_configvalue("error-log").length() > 0) {
 		try {
-			logger::getInstance().set_errorlogfile(
-				cfg.get_configvalue("error-log"));
-		} catch (const exception& e) {
+			Logger::set_user_error_logfile(cfg.get_configvalue("error-log"));
+		} catch (const Exception& e) {
 			const std::string msg =
 				strprintf::fmt("Couldn't open %s: %s",
 					cfg.get_configvalue("error-log"),
@@ -1148,7 +853,7 @@ void controller::update_config()
 	}
 }
 
-void controller::load_configfile(const std::string& filename)
+void Controller::load_configfile(const std::string& filename)
 {
 	if (cfgparser.parse(filename, true)) {
 		update_config();
@@ -1159,7 +864,7 @@ void controller::load_configfile(const std::string& filename)
 	}
 }
 
-void controller::dump_config(const std::string& filename)
+void Controller::dump_config(const std::string& filename)
 {
 	std::vector<std::string> configlines;
 	cfg.dump_config(configlines);
@@ -1179,7 +884,7 @@ void controller::dump_config(const std::string& filename)
 	}
 }
 
-void controller::update_flags(std::shared_ptr<rss_item> item)
+void Controller::update_flags(std::shared_ptr<RssItem> item)
 {
 	if (api) {
 		api->update_article_flags(
