@@ -8,34 +8,34 @@
 
 namespace newsboat {
 
-filtercontainer::~filtercontainer() {}
+FilterContainer::~FilterContainer() {}
 
-void filtercontainer::handle_action(const std::string& action,
+void FilterContainer::handle_action(const std::string& action,
 	const std::vector<std::string>& params)
 {
 	/*
-	 * filtercontainer does nothing but to save (filter name, filter
+	 * FilterContainer does nothing but to save (filter name, filter
 	 * expression) tuples. These tuples are used for enabling the user to
 	 * predefine filter expressions and then select them from a list by
 	 * their name.
 	 */
 	if (action == "define-filter") {
 		if (params.size() < 2)
-			throw confighandlerexception(
-				action_handler_status::TOO_FEW_PARAMS);
-		matcher m;
+			throw ConfigHandlerException(
+				ActionHandlerStatus::TOO_FEW_PARAMS);
+		Matcher m;
 		if (!m.parse(params[1]))
-			throw confighandlerexception(strprintf::fmt(
+			throw ConfigHandlerException(strprintf::fmt(
 				_("couldn't parse filter expression `%s': %s"),
 				params[1],
 				m.get_parse_error()));
-		filters.push_back(filter_name_expr_pair(params[0], params[1]));
+		filters.push_back(FilterNameExprPair(params[0], params[1]));
 	} else
-		throw confighandlerexception(
-			action_handler_status::INVALID_COMMAND);
+		throw ConfigHandlerException(
+			ActionHandlerStatus::INVALID_COMMAND);
 }
 
-void filtercontainer::dump_config(std::vector<std::string>& config_output)
+void FilterContainer::dump_config(std::vector<std::string>& config_output)
 {
 	for (const auto& filter : filters) {
 		config_output.push_back(strprintf::fmt("define-filter %s %s",
