@@ -9,24 +9,24 @@
 
 namespace newsboat {
 
-listformatter::listformatter() {}
+ListFormatter::ListFormatter() {}
 
-listformatter::~listformatter() {}
+ListFormatter::~ListFormatter() {}
 
-void listformatter::add_line(const std::string& text,
+void ListFormatter::add_line(const std::string& text,
 	unsigned int id,
 	unsigned int width)
 {
 	set_line(UINT_MAX, text, id, width);
-	LOG(level::DEBUG, "listformatter::add_line: `%s'", text);
+	LOG(Level::DEBUG, "ListFormatter::add_line: `%s'", text);
 }
 
-void listformatter::set_line(const unsigned int itempos,
+void ListFormatter::set_line(const unsigned int itempos,
 	const std::string& text,
 	unsigned int id,
 	unsigned int width)
 {
-	std::vector<line_id_pair> formatted_text;
+	std::vector<LineIdPair> formatted_text;
 
 	if (width > 0 && text.length() > 0) {
 		std::wstring mytext = utils::clean_nonprintable_characters(
@@ -42,12 +42,12 @@ void listformatter::set_line(const unsigned int itempos,
 					size--;
 				}
 			}
-			formatted_text.push_back(line_id_pair(
+			formatted_text.push_back(LineIdPair(
 				utils::wstr2str(mytext.substr(0, size)), id));
 			mytext.erase(0, size);
 		}
 	} else {
-		formatted_text.push_back(line_id_pair(
+		formatted_text.push_back(LineIdPair(
 			utils::wstr2str(utils::clean_nonprintable_characters(
 				utils::str2wstr(text))),
 			id));
@@ -62,7 +62,7 @@ void listformatter::set_line(const unsigned int itempos,
 	}
 }
 
-void listformatter::add_lines(const std::vector<std::string>& thelines,
+void ListFormatter::add_lines(const std::vector<std::string>& thelines,
 	unsigned int width)
 {
 	for (const auto& line : thelines) {
@@ -72,7 +72,7 @@ void listformatter::add_lines(const std::vector<std::string>& thelines,
 	}
 }
 
-std::string listformatter::format_list(regexmanager* rxman,
+std::string ListFormatter::format_list(RegexManager* rxman,
 	const std::string& location)
 {
 	format_cache = "{list";
@@ -82,12 +82,12 @@ std::string listformatter::format_list(regexmanager* rxman,
 			rxman->quote_and_highlight(str, location);
 		if (line.second == UINT_MAX) {
 			format_cache.append(strprintf::fmt(
-				"{listitem text:%s}", stfl::quote(str)));
+				"{listitem text:%s}", Stfl::quote(str)));
 		} else {
 			format_cache.append(
 				strprintf::fmt("{listitem[%u] text:%s}",
 					line.second,
-					stfl::quote(str)));
+					Stfl::quote(str)));
 		}
 	}
 	format_cache.append(1, '}');
