@@ -24,7 +24,7 @@ static int progress_callback(void* clientp,
 	double ultotal,
 	double ulnow);
 
-poddlthread::poddlthread(download* dl_, newsboat::configcontainer* c)
+PodDlThread::PodDlThread(Download* dl_, newsboat::ConfigContainer* c)
 	: dl(dl_)
 	, f(new std::ofstream())
 	, bytecount(0)
@@ -35,14 +35,14 @@ poddlthread::poddlthread(download* dl_, newsboat::configcontainer* c)
 	tv2 = zero;
 }
 
-poddlthread::~poddlthread() {}
+PodDlThread::~PodDlThread() {}
 
-void poddlthread::operator()()
+void PodDlThread::operator()()
 {
 	run();
 }
 
-void poddlthread::run()
+void PodDlThread::run()
 {
 	// are we resuming previous download?
 	bool resumed_download = false;
@@ -75,11 +75,11 @@ void poddlthread::run()
 
 	struct stat sb;
 	std::string filename =
-		dl->filename() + newsboat::configcontainer::PARTIAL_FILE_SUFFIX;
+		dl->filename() + newsboat::ConfigContainer::PARTIAL_FILE_SUFFIX;
 
 	if (stat(filename.c_str(), &sb) == -1) {
-		LOG(level::INFO,
-			"poddlthread::run: stat failed: starting normal "
+		LOG(Level::INFO,
+			"PodDlThread::run: stat failed: starting normal "
 			"download");
 
 		// Have to copy the string into a vector in order to be able to
@@ -92,8 +92,8 @@ void poddlthread::run()
 		dl->set_offset(0);
 		resumed_download = false;
 	} else {
-		LOG(level::INFO,
-			"poddlthread::run: stat ok: starting download from %u",
+		LOG(Level::INFO,
+			"PodDlThread::run: stat ok: starting download from %u",
 			sb.st_size);
 		curl_easy_setopt(easyhandle, CURLOPT_RESUME_FROM, sb.st_size);
 		dl->set_offset(sb.st_size);
@@ -102,35 +102,35 @@ void poddlthread::run()
 	}
 
 	if (f->is_open()) {
-		dl->set_status(dlstatus::DOWNLOADING);
+		dl->set_status(DlStatus::DOWNLOADING);
 
 		CURLcode success = curl_easy_perform(easyhandle);
 
 		f->close();
 
-		LOG(level::INFO,
-			"poddlthread::run: curl_easy_perform rc = %u (%s)",
+		LOG(Level::INFO,
+			"PodDlThread::run: curl_easy_perform rc = %u (%s)",
 			success,
 			curl_easy_strerror(success));
 
 		if (0 == success) {
-			LOG(level::DEBUG,
-				"poddlthread::run: download complete, deleting "
+			LOG(Level::DEBUG,
+				"PodDlThread::run: download complete, deleting "
 				"temporary suffix");
 			rename(filename.c_str(), dl->filename().c_str());
-			dl->set_status(dlstatus::READY);
-		} else if (dl->status() != dlstatus::CANCELLED) {
+			dl->set_status(DlStatus::READY);
+		} else if (dl->status() != DlStatus::CANCELLED) {
 			// attempt complete re-download
 			if (resumed_download) {
 				::unlink(filename.c_str());
 				this->run();
 			} else {
-				dl->set_status(dlstatus::FAILED);
+				dl->set_status(DlStatus::FAILED);
 				::unlink(filename.c_str());
 			}
 		}
 	} else {
-		dl->set_status(dlstatus::FAILED);
+		dl->set_status(DlStatus::FAILED);
 	}
 
 	curl_easy_cleanup(easyhandle);
@@ -139,7 +139,7 @@ void poddlthread::run()
 static size_t
 my_write_data(void* buffer, size_t size, size_t nmemb, void* userp)
 {
-	poddlthread* thread = static_cast<poddlthread*>(userp);
+	PodDlThread* thread = static_cast<PodDlThread*>(userp);
 	return thread->write_data(buffer, size, nmemb);
 }
 
@@ -149,26 +149,26 @@ static int progress_callback(void* clientp,
 	double /* ultotal */,
 	double /*ulnow*/)
 {
-	poddlthread* thread = static_cast<poddlthread*>(clientp);
+	PodDlThread* thread = static_cast<PodDlThread*>(clientp);
 	return thread->progress(dlnow, dltotal);
 }
 
-size_t poddlthread::write_data(void* buffer, size_t size, size_t nmemb)
+size_t PodDlThread::write_data(void* buffer, size_t size, size_t nmemb)
 {
-	if (dl->status() == dlstatus::CANCELLED)
+	if (dl->status() == DlStatus::CANCELLED)
 		return 0;
 	f->write(static_cast<char*>(buffer), size * nmemb);
 	bytecount += (size * nmemb);
-	LOG(level::DEBUG,
-		"poddlthread::write_data: bad = %u size = %u",
+	LOG(Level::DEBUG,
+		"PodDlThread::write_data: bad = %u size = %u",
 		f->bad(),
 		size * nmemb);
 	return f->bad() ? 0 : size * nmemb;
 }
 
-int poddlthread::progress(double dlnow, double dltotal)
+int PodDlThread::progress(double dlnow, double dltotal)
 {
-	if (dl->status() == dlstatus::CANCELLED)
+	if (dl->status() == DlStatus::CANCELLED)
 		return -1;
 	gettimeofday(&tv2, nullptr);
 	double kbps = compute_kbps();
@@ -182,7 +182,7 @@ int poddlthread::progress(double dlnow, double dltotal)
 	return 0;
 }
 
-double poddlthread::compute_kbps()
+double PodDlThread::compute_kbps()
 {
 	double t1 = tv1.tv_sec + (tv1.tv_usec / 1000000.0);
 	double t2 = tv2.tv_sec + (tv2.tv_usec / 1000000.0);
