@@ -24,7 +24,7 @@
 
 namespace newsboat {
 
-rss_item::rss_item(cache* c)
+RssItem::RssItem(Cache* c)
 	: ch(c)
 	, idx(0)
 	, size_(0)
@@ -36,54 +36,54 @@ rss_item::rss_item(cache* c)
 {
 }
 
-rss_item::~rss_item() {}
+RssItem::~RssItem() {}
 
-rss_feed::rss_feed(cache* c)
+RssFeed::RssFeed(Cache* c)
 	: pubDate_(0)
 	, ch(c)
 	, empty(true)
 	, is_rtl_(false)
 	, idx(0)
 	, order(0)
-	, status_(dl_status::SUCCESS)
+	, status_(DlStatus::SUCCESS)
 {
 }
 
-rss_feed::~rss_feed()
+RssFeed::~RssFeed()
 {
 	clear_items();
 }
 
-// rss_item setters
+// RssItem setters
 
-void rss_item::set_title(const std::string& t)
+void RssItem::set_title(const std::string& t)
 {
 	title_ = t;
 	utils::trim(title_);
 }
 
-void rss_item::set_link(const std::string& l)
+void RssItem::set_link(const std::string& l)
 {
 	link_ = l;
 	utils::trim(link_);
 }
 
-void rss_item::set_author(const std::string& a)
+void RssItem::set_author(const std::string& a)
 {
 	author_ = a;
 }
 
-void rss_item::set_description(const std::string& d)
+void RssItem::set_description(const std::string& d)
 {
 	description_ = d;
 }
 
-void rss_item::set_size(unsigned int size)
+void RssItem::set_size(unsigned int size)
 {
 	size_ = size;
 }
 
-std::string rss_item::length() const
+std::string RssItem::length() const
 {
 	std::string::size_type l(size_);
 	if (!l)
@@ -96,37 +96,37 @@ std::string rss_item::length() const
 	return strprintf::fmt("%.1fM", l / 1024.0 / 1024.0);
 }
 
-void rss_item::set_pubDate(time_t t)
+void RssItem::set_pubDate(time_t t)
 {
 	pubDate_ = t;
 }
 
-void rss_item::set_guid(const std::string& g)
+void RssItem::set_guid(const std::string& g)
 {
 	guid_ = g;
 }
 
-void rss_item::set_unread_nowrite(bool u)
+void RssItem::set_unread_nowrite(bool u)
 {
 	unread_ = u;
 }
 
-void rss_item::set_unread_nowrite_notify(bool u, bool notify)
+void RssItem::set_unread_nowrite_notify(bool u, bool notify)
 {
 	unread_ = u;
-	std::shared_ptr<rss_feed> feedptr = feedptr_.lock();
+	std::shared_ptr<RssFeed> feedptr = feedptr_.lock();
 	if (feedptr && notify) {
 		feedptr->get_item_by_guid(guid_)->set_unread_nowrite(
 			unread_); // notify parent feed
 	}
 }
 
-void rss_item::set_unread(bool u)
+void RssItem::set_unread(bool u)
 {
 	if (unread_ != u) {
 		bool old_u = unread_;
 		unread_ = u;
-		std::shared_ptr<rss_feed> feedptr = feedptr_.lock();
+		std::shared_ptr<RssFeed> feedptr = feedptr_.lock();
 		if (feedptr)
 			feedptr->get_item_by_guid(guid_)->set_unread_nowrite(
 				unread_); // notify parent feed
@@ -135,7 +135,7 @@ void rss_item::set_unread(bool u)
 				ch->update_rssitem_unread_and_enqueued(
 					this, feedurl_);
 			}
-		} catch (const dbexception& e) {
+		} catch (const DbException& e) {
 			// if the update failed, restore the old unread flag and
 			// rethrow the exception
 			unread_ = old_u;
@@ -144,7 +144,7 @@ void rss_item::set_unread(bool u)
 	}
 }
 
-std::string rss_item::pubDate() const
+std::string RssItem::pubDate() const
 {
 	char text[1024];
 	strftime(text,
@@ -154,17 +154,17 @@ std::string rss_item::pubDate() const
 	return std::string(text);
 }
 
-unsigned int rss_feed::unread_item_count()
+unsigned int RssFeed::unread_item_count()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	return std::count_if(items_.begin(),
 		items_.end(),
-		[](const std::shared_ptr<rss_item>& item) {
+		[](const std::shared_ptr<RssItem>& item) {
 			return item->unread();
 		});
 }
 
-bool rss_feed::matches_tag(const std::string& tag)
+bool RssFeed::matches_tag(const std::string& tag)
 {
 	return std::find_if(
 		       tags_.begin(), tags_.end(), [&](const std::string& t) {
@@ -172,12 +172,12 @@ bool rss_feed::matches_tag(const std::string& tag)
 		       }) != tags_.end();
 }
 
-std::string rss_feed::get_firsttag()
+std::string RssFeed::get_firsttag()
 {
 	return tags_.empty() ? "" : tags_.front();
 }
 
-std::string rss_feed::get_tags()
+std::string RssFeed::get_tags()
 {
 	std::string tags;
 	for (const auto& t : tags_) {
@@ -189,22 +189,22 @@ std::string rss_feed::get_tags()
 	return tags;
 }
 
-void rss_feed::set_tags(const std::vector<std::string>& tags)
+void RssFeed::set_tags(const std::vector<std::string>& tags)
 {
 	tags_ = tags;
 }
 
-void rss_item::set_enclosure_url(const std::string& url)
+void RssItem::set_enclosure_url(const std::string& url)
 {
 	enclosure_url_ = url;
 }
 
-void rss_item::set_enclosure_type(const std::string& type)
+void RssItem::set_enclosure_type(const std::string& type)
 {
 	enclosure_type_ = type;
 }
 
-std::string rss_item::title() const
+std::string RssItem::title() const
 {
 	std::string retval;
 	if (title_.length() > 0)
@@ -213,17 +213,17 @@ std::string rss_item::title() const
 	return retval;
 }
 
-std::string rss_item::author() const
+std::string RssItem::author() const
 {
 	return utils::convert_text(author_, nl_langinfo(CODESET), "utf-8");
 }
 
-std::string rss_item::description() const
+std::string RssItem::description() const
 {
 	return utils::convert_text(description_, nl_langinfo(CODESET), "utf-8");
 }
 
-std::string rss_feed::title() const
+std::string RssFeed::title() const
 {
 	bool found_title = false;
 	std::string alt_title;
@@ -239,42 +239,42 @@ std::string rss_feed::title() const
 		: utils::convert_text(title_, nl_langinfo(CODESET), "utf-8");
 }
 
-std::string rss_feed::description() const
+std::string RssFeed::description() const
 {
 	return utils::convert_text(description_, nl_langinfo(CODESET), "utf-8");
 }
 
-bool rss_feed::hidden() const
+bool RssFeed::hidden() const
 {
 	return std::any_of(tags_.begin(),
 		tags_.end(),
 		[](const std::string& tag) { return tag.substr(0, 1) == "!"; });
 }
 
-std::shared_ptr<rss_item> rss_feed::get_item_by_guid(const std::string& guid)
+std::shared_ptr<RssItem> RssFeed::get_item_by_guid(const std::string& guid)
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	return get_item_by_guid_unlocked(guid);
 }
 
-std::shared_ptr<rss_item> rss_feed::get_item_by_guid_unlocked(
+std::shared_ptr<RssItem> RssFeed::get_item_by_guid_unlocked(
 	const std::string& guid)
 {
 	auto it = items_guid_map.find(guid);
 	if (it != items_guid_map.end()) {
 		return it->second;
 	}
-	LOG(level::DEBUG,
-		"rss_feed::get_item_by_guid_unlocked: hit dummy item!");
-	LOG(level::DEBUG,
-		"rss_feed::get_item_by_guid_unlocked: items_guid_map.size = %d",
+	LOG(Level::DEBUG,
+		"RssFeed::get_item_by_guid_unlocked: hit dummy item!");
+	LOG(Level::DEBUG,
+		"RssFeed::get_item_by_guid_unlocked: items_guid_map.size = %d",
 		items_guid_map.size());
 	// abort();
-	return std::shared_ptr<rss_item>(
-		new rss_item(ch)); // should never happen!
+	return std::shared_ptr<RssItem>(
+		new RssItem(ch)); // should never happen!
 }
 
-bool rss_item::has_attribute(const std::string& attribname)
+bool RssItem::has_attribute(const std::string& attribname)
 {
 	if (attribname == "title" || attribname == "link" ||
 		attribname == "author" || attribname == "content" ||
@@ -285,14 +285,14 @@ bool rss_item::has_attribute(const std::string& attribname)
 		return true;
 
 	// if we have a feed, then forward the request
-	std::shared_ptr<rss_feed> feedptr = feedptr_.lock();
+	std::shared_ptr<RssFeed> feedptr = feedptr_.lock();
 	if (feedptr)
-		return feedptr->rss_feed::has_attribute(attribname);
+		return feedptr->RssFeed::has_attribute(attribname);
 
 	return false;
 }
 
-std::string rss_item::get_attribute(const std::string& attribname)
+std::string RssItem::get_attribute(const std::string& attribname)
 {
 	if (attribname == "title")
 		return title();
@@ -321,28 +321,28 @@ std::string rss_item::get_attribute(const std::string& attribname)
 		return std::to_string(idx);
 
 	// if we have a feed, then forward the request
-	std::shared_ptr<rss_feed> feedptr = feedptr_.lock();
+	std::shared_ptr<RssFeed> feedptr = feedptr_.lock();
 	if (feedptr)
-		return feedptr->rss_feed::get_attribute(attribname);
+		return feedptr->RssFeed::get_attribute(attribname);
 
 	return "";
 }
 
-void rss_item::update_flags()
+void RssItem::update_flags()
 {
 	if (ch) {
 		ch->update_rssitem_flags(this);
 	}
 }
 
-void rss_item::set_flags(const std::string& ff)
+void RssItem::set_flags(const std::string& ff)
 {
 	oldflags_ = flags_;
 	flags_ = ff;
 	sort_flags();
 }
 
-void rss_item::sort_flags()
+void RssItem::sort_flags()
 {
 	std::sort(flags_.begin(), flags_.end());
 
@@ -356,7 +356,7 @@ void rss_item::sort_flags()
 	flags_.erase(std::unique(flags_.begin(), flags_.end()), flags_.end());
 }
 
-bool rss_feed::has_attribute(const std::string& attribname)
+bool RssFeed::has_attribute(const std::string& attribname)
 {
 	if (attribname == "feedtitle" || attribname == "description" ||
 		attribname == "feedlink" || attribname == "feeddate" ||
@@ -367,7 +367,7 @@ bool rss_feed::has_attribute(const std::string& attribname)
 	return false;
 }
 
-std::string rss_feed::get_attribute(const std::string& attribname)
+std::string RssFeed::get_attribute(const std::string& attribname)
 {
 	if (attribname == "feedtitle")
 		return title();
@@ -391,23 +391,23 @@ std::string rss_feed::get_attribute(const std::string& attribname)
 	return "";
 }
 
-void rss_ignores::handle_action(const std::string& action,
+void RssIgnores::handle_action(const std::string& action,
 	const std::vector<std::string>& params)
 {
 	if (action == "ignore-article") {
 		if (params.size() < 2)
-			throw confighandlerexception(
-				action_handler_status::TOO_FEW_PARAMS);
+			throw ConfigHandlerException(
+				ActionHandlerStatus::TOO_FEW_PARAMS);
 		std::string ignore_rssurl = params[0];
 		std::string ignore_expr = params[1];
-		matcher m;
+		Matcher m;
 		if (!m.parse(ignore_expr))
-			throw confighandlerexception(strprintf::fmt(
+			throw ConfigHandlerException(strprintf::fmt(
 				_("couldn't parse filter expression `%s': %s"),
 				ignore_expr,
 				m.get_parse_error()));
-		ignores.push_back(feedurl_expr_pair(
-			ignore_rssurl, new matcher(ignore_expr)));
+		ignores.push_back(FeedUrlExprPair(
+			ignore_rssurl, new Matcher(ignore_expr)));
 	} else if (action == "always-download") {
 		for (const auto& param : params) {
 			ignores_lastmodified.push_back(param);
@@ -417,11 +417,11 @@ void rss_ignores::handle_action(const std::string& action,
 			resetflag.push_back(param);
 		}
 	} else
-		throw confighandlerexception(
-			action_handler_status::INVALID_COMMAND);
+		throw ConfigHandlerException(
+			ActionHandlerStatus::INVALID_COMMAND);
 }
 
-void rss_ignores::dump_config(std::vector<std::string>& config_output)
+void RssIgnores::dump_config(std::vector<std::string>& config_output)
 {
 	for (const auto& ign : ignores) {
 		std::string configline = "ignore-article ";
@@ -443,26 +443,26 @@ void rss_ignores::dump_config(std::vector<std::string>& config_output)
 	}
 }
 
-rss_ignores::~rss_ignores()
+RssIgnores::~RssIgnores()
 {
 	for (const auto& ign : ignores) {
 		delete ign.second;
 	}
 }
 
-bool rss_ignores::matches(rss_item* item)
+bool RssIgnores::matches(RssItem* item)
 {
 	for (const auto& ign : ignores) {
-		LOG(level::DEBUG,
-			"rss_ignores::matches: ign.first = `%s' item->feedurl "
+		LOG(Level::DEBUG,
+			"RssIgnores::matches: ign.first = `%s' item->feedurl "
 			"= "
 			"`%s'",
 			ign.first,
 			item->feedurl());
 		if (ign.first == "*" || item->feedurl() == ign.first) {
 			if (ign.second->matches(item)) {
-				LOG(level::DEBUG,
-					"rss_ignores::matches: found match");
+				LOG(Level::DEBUG,
+					"RssIgnores::matches: found match");
 				return true;
 			}
 		}
@@ -470,7 +470,7 @@ bool rss_ignores::matches(rss_item* item)
 	return false;
 }
 
-bool rss_ignores::matches_lastmodified(const std::string& url)
+bool RssIgnores::matches_lastmodified(const std::string& url)
 {
 	return std::find_if(ignores_lastmodified.begin(),
 		       ignores_lastmodified.end(),
@@ -478,7 +478,7 @@ bool rss_ignores::matches_lastmodified(const std::string& url)
 		ignores_lastmodified.end();
 }
 
-bool rss_ignores::matches_resetunread(const std::string& url)
+bool RssIgnores::matches_resetunread(const std::string& url)
 {
 	return std::find_if(resetflag.begin(),
 		       resetflag.end(),
@@ -486,18 +486,18 @@ bool rss_ignores::matches_resetunread(const std::string& url)
 		resetflag.end();
 }
 
-void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
+void RssFeed::update_items(std::vector<std::shared_ptr<RssFeed>> feeds)
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	if (query.length() == 0)
 		return;
 
-	LOG(level::DEBUG, "rss_feed::update_items: query = `%s'", query);
+	LOG(Level::DEBUG, "RssFeed::update_items: query = `%s'", query);
 
 	struct timeval tv1, tv2, tvx;
 	gettimeofday(&tv1, nullptr);
 
-	matcher m(query);
+	Matcher m(query);
 
 	items_.clear();
 	items_guid_map.clear();
@@ -506,9 +506,9 @@ void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
 		if (!feed->is_query_feed()) { // don't fetch items from other query feeds!
 			for (const auto& item : feed->items()) {
 				if (m.matches(item.get())) {
-					LOG(level::DEBUG,
-						"rss_feed::update_items: "
-						"matcher "
+					LOG(Level::DEBUG,
+						"RssFeed::update_items: "
+						"Matcher "
 						"matches!");
 					item->set_feedptr(feed);
 					items_.push_back(item);
@@ -529,17 +529,17 @@ void rss_feed::update_items(std::vector<std::shared_ptr<rss_feed>> feeds)
 	unsigned long diffx =
 		(((tv2.tv_sec - tvx.tv_sec) * 1000000) + tv2.tv_usec) -
 		tvx.tv_usec;
-	LOG(level::DEBUG,
-		"rss_feed::update_items matching took %lu.%06lu s",
+	LOG(Level::DEBUG,
+		"RssFeed::update_items matching took %lu.%06lu s",
 		diff / 1000000,
 		diff % 1000000);
-	LOG(level::DEBUG,
-		"rss_feed::update_items sorting took %lu.%06lu s",
+	LOG(Level::DEBUG,
+		"RssFeed::update_items sorting took %lu.%06lu s",
 		diffx / 1000000,
 		diffx % 1000000);
 }
 
-void rss_feed::set_rssurl(const std::string& u)
+void RssFeed::set_rssurl(const std::string& u)
 {
 	rssurl_ = u;
 	if (utils::is_query_url(u)) {
@@ -564,15 +564,15 @@ void rss_feed::set_rssurl(const std::string& u)
 			query += *it;
 		}
 		// Have to check if the result is a valid query, just in case
-		matcher m;
+		Matcher m;
 		if (!m.parse(query)) {
 			throw strprintf::fmt(
 				_("`%s' is not a valid filter expression"),
 				query);
 		}
 
-		LOG(level::DEBUG,
-			"rss_feed::set_rssurl: query name = `%s' expr = `%s'",
+		LOG(Level::DEBUG,
+			"RssFeed::set_rssurl: query name = `%s' expr = `%s'",
 			tokens[1],
 			query);
 
@@ -581,87 +581,87 @@ void rss_feed::set_rssurl(const std::string& u)
 	}
 }
 
-void rss_feed::sort(const ArticleSortStrategy& sort_strategy)
+void RssFeed::sort(const ArticleSortStrategy& sort_strategy)
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	sort_unlocked(sort_strategy);
 }
 
-void rss_feed::sort_unlocked(const ArticleSortStrategy& sort_strategy)
+void RssFeed::sort_unlocked(const ArticleSortStrategy& sort_strategy)
 {
 	switch (sort_strategy.sm) {
-	case art_sort_method_t::TITLE:
+	case ArtSortMethod::TITLE:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				return sort_strategy.sd ==
-						sort_direction_t::DESC
+						SortDirection::DESC
 					? (utils::strnaturalcmp(a->title().c_str(),
 						   b->title().c_str()) > 0)
 					: (utils::strnaturalcmp(a->title().c_str(),
 						   b->title().c_str()) < 0);
 			});
 		break;
-	case art_sort_method_t::FLAGS:
+	case ArtSortMethod::FLAGS:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				return sort_strategy.sd ==
-						sort_direction_t::DESC
+						SortDirection::DESC
 					? (strcmp(a->flags().c_str(),
 						   b->flags().c_str()) > 0)
 					: (strcmp(a->flags().c_str(),
 						   b->flags().c_str()) < 0);
 			});
 		break;
-	case art_sort_method_t::AUTHOR:
+	case ArtSortMethod::AUTHOR:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				return sort_strategy.sd ==
-						sort_direction_t::DESC
+						SortDirection::DESC
 					? (strcmp(a->author().c_str(),
 						   b->author().c_str()) > 0)
 					: (strcmp(a->author().c_str(),
 						   b->author().c_str()) < 0);
 			});
 		break;
-	case art_sort_method_t::LINK:
+	case ArtSortMethod::LINK:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				return sort_strategy.sd ==
-						sort_direction_t::DESC
+						SortDirection::DESC
 					? (strcmp(a->link().c_str(),
 						   b->link().c_str()) > 0)
 					: (strcmp(a->link().c_str(),
 						   b->link().c_str()) < 0);
 			});
 		break;
-	case art_sort_method_t::GUID:
+	case ArtSortMethod::GUID:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				return sort_strategy.sd ==
-						sort_direction_t::DESC
+						SortDirection::DESC
 					? (strcmp(a->guid().c_str(),
 						   b->guid().c_str()) > 0)
 					: (strcmp(a->guid().c_str(),
 						   b->guid().c_str()) < 0);
 			});
 		break;
-	case art_sort_method_t::DATE:
+	case ArtSortMethod::DATE:
 		std::stable_sort(items_.begin(),
 			items_.end(),
-			[&](std::shared_ptr<rss_item> a,
-				std::shared_ptr<rss_item> b) {
+			[&](std::shared_ptr<RssItem> a,
+				std::shared_ptr<RssItem> b) {
 				// date is descending by default
-				return sort_strategy.sd == sort_direction_t::ASC
+				return sort_strategy.sd == SortDirection::ASC
 					? (a->pubDate_timestamp() >
 						  b->pubDate_timestamp())
 					: (a->pubDate_timestamp() <
@@ -671,7 +671,7 @@ void rss_feed::sort_unlocked(const ArticleSortStrategy& sort_strategy)
 	}
 }
 
-void rss_feed::remove_old_deleted_items()
+void RssFeed::remove_old_deleted_items()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	std::vector<std::string> guids;
@@ -681,10 +681,10 @@ void rss_feed::remove_old_deleted_items()
 	ch->remove_old_deleted_items(rssurl_, guids);
 }
 
-void rss_feed::purge_deleted_items()
+void RssFeed::purge_deleted_items()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
-	scope_measure m1("rss_feed::purge_deleted_items");
+	ScopeMeasure m1("RssFeed::purge_deleted_items");
 
 	// Purge in items_guid_map
 	{
@@ -698,13 +698,13 @@ void rss_feed::purge_deleted_items()
 
 	items_.erase(std::remove_if(items_.begin(),
 			     items_.end(),
-			     [](const std::shared_ptr<rss_item> item) {
+			     [](const std::shared_ptr<RssItem> item) {
 				     return item->deleted();
 			     }),
 		items_.end());
 }
 
-void rss_feed::set_feedptrs(std::shared_ptr<rss_feed> self)
+void RssFeed::set_feedptrs(std::shared_ptr<RssFeed> self)
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	for (const auto& item : items_) {
@@ -712,27 +712,27 @@ void rss_feed::set_feedptrs(std::shared_ptr<rss_feed> self)
 	}
 }
 
-void rss_item::set_feedptr(std::shared_ptr<rss_feed> ptr)
+void RssItem::set_feedptr(std::shared_ptr<RssFeed> ptr)
 {
-	feedptr_ = std::weak_ptr<rss_feed>(ptr);
+	feedptr_ = std::weak_ptr<RssFeed>(ptr);
 }
 
-std::string rss_feed::get_status()
+std::string RssFeed::get_status()
 {
 	switch (status_) {
-	case dl_status::SUCCESS:
+	case DlStatus::SUCCESS:
 		return " ";
-	case dl_status::TO_BE_DOWNLOADED:
+	case DlStatus::TO_BE_DOWNLOADED:
 		return "_";
-	case dl_status::DURING_DOWNLOAD:
+	case DlStatus::DURING_DOWNLOAD:
 		return ".";
-	case dl_status::DL_ERROR:
+	case DlStatus::DL_ERROR:
 		return "x";
 	}
 	return "?";
 }
 
-void rss_feed::unload()
+void RssFeed::unload()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	for (const auto& item : items_) {
@@ -740,13 +740,13 @@ void rss_feed::unload()
 	}
 }
 
-void rss_feed::load()
+void RssFeed::load()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	ch->fetch_descriptions(this);
 }
 
-void rss_feed::mark_all_items_read()
+void RssFeed::mark_all_items_read()
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
 	for (const auto& item : items_) {
