@@ -15,6 +15,7 @@
 #include <libgen.h>
 #include <libxml/uri.h>
 #include <locale>
+#include <mutex>
 #include <pwd.h>
 #include <regex>
 #include <sstream>
@@ -43,8 +44,40 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #include <openssl/crypto.h>
 #endif
 
+#include "rs_utils.h"
+
 namespace newsboat {
 
+namespace utils {
+void append_escapes(std::string& str, char c)
+{
+	switch (c) {
+	case 'n':
+		str.append("\n");
+		break;
+	case 'r':
+		str.append("\r");
+		break;
+	case 't':
+		str.append("\t");
+		break;
+	case '"':
+		str.append("\"");
+		break;
+	// escaped backticks are passed through, still escaped. We un-escape
+	// them in ConfigParser::evaluate_backticks
+	case '`':
+		str.append("\\`");
+		break;
+	case '\\':
+		break;
+	default:
+		str.append(1, c);
+		break;
+	}
+}
+}
+
 std::vector<std::string> utils::tokenize_quoted(const std::string& str,
 	std::string delimiters)
 {
@@ -211,26 +244,9 @@ std::vector<std::string> utils::tokenize_spaced(const std::string& str,
 	return tokens;
 }
 
-std::string utils::consolidate_whitespace(const std::string& str,
-	std::string whitespace)
-{
-	std::string result;
-	std::string::size_type last_pos = str.find_first_not_of(whitespace);
-	std::string::size_type pos = str.find_first_of(whitespace, last_pos);
+std::string utils::consolidate_whitespace(const std::string& str) {
 
-	if (last_pos != 0 && str != "") {
-		result.append(str.substr(0, last_pos));
-	}
-
-	while (std::string::npos != pos || std::string::npos != last_pos) {
-		result.append(str.substr(last_pos, pos - last_pos));
-		last_pos = str.find_first_not_of(whitespace, pos);
-		if (last_pos > pos)
-			result.append(" ");
-		pos = str.find_first_of(whitespace, last_pos);
-	}
-
-	return result;
+	return RustString(rs_consolidate_whitespace(str.c_str()));
 }
 
 std::vector<std::string> utils::tokenize_nl(const std::string& str,
@@ -241,7 +257,7 @@ std::vector<std::string> utils::tokenize_nl(const std::string& str,
 	std::string::size_type pos = str.find_first_of(delimiters, last_pos);
 	unsigned int i;
 
-	LOG(level::DEBUG, "utils::tokenize_nl: last_pos = %u", last_pos);
+	LOG(Level::DEBUG, "utils::tokenize_nl: last_pos = %u", last_pos);
 	if (last_pos != std::string::npos) {
 		for (i = 0; i < last_pos; ++i) {
 			tokens.push_back(std::string("\n"));
@@ -250,11 +266,11 @@ std::vector<std::string> utils::tokenize_nl(const std::string& str,
 
 	while (std::string::npos != pos || std::string::npos != last_pos) {
 		tokens.push_back(str.substr(last_pos, pos - last_pos));
-		LOG(level::DEBUG,
+		LOG(Level::DEBUG,
 			"utils::tokenize_nl: substr = %s",
 			str.substr(last_pos, pos - last_pos));
 		last_pos = str.find_first_not_of(delimiters, pos);
-		LOG(level::DEBUG,
+		LOG(Level::DEBUG,
 			"utils::tokenize_nl: pos - last_pos = %u",
 			last_pos - pos);
 		for (i = 0; last_pos != std::string::npos &&
@@ -273,15 +289,15 @@ std::string utils::translit(const std::string& tocode,
 {
 	std::string tlit = "//TRANSLIT";
 
-	enum class translit_state { UNKNOWN, SUPPORTED, UNSUPPORTED };
+	enum class TranslitState { UNKNOWN, SUPPORTED, UNSUPPORTED };
 
-	static translit_state state = translit_state::UNKNOWN;
+	static TranslitState state = TranslitState::UNKNOWN;
 
 	// TRANSLIT is not needed when converting to unicode encodings
 	if (tocode == "utf-8" || tocode == "WCHAR_T")
 		return tocode;
 
-	if (state == translit_state::UNKNOWN) {
+	if (state == TranslitState::UNKNOWN) {
 		iconv_t cd = ::iconv_open(
 			(tocode + "//TRANSLIT").c_str(), fromcode.c_str());
 
@@ -290,7 +306,7 @@ std::string utils::translit(const std::string& tocode,
 				iconv_t cd = ::iconv_open(
 					tocode.c_str(), fromcode.c_str());
 				if (cd != reinterpret_cast<iconv_t>(-1)) {
-					state = translit_state::UNSUPPORTED;
+					state = TranslitState::UNSUPPORTED;
 				} else {
 					fprintf(stderr,
 						"iconv_open('%s', '%s') "
@@ -310,13 +326,13 @@ std::string utils::translit(const std::string& tocode,
 				abort();
 			}
 		} else {
-			state = translit_state::SUPPORTED;
+			state = TranslitState::SUPPORTED;
 		}
 
 		iconv_close(cd);
 	}
 
-	return ((state == translit_state::SUPPORTED) ? (tocode + tlit)
+	return ((state == TranslitState::SUPPORTED) ? (tocode + tlit)
 						     : (tocode));
 }
 
@@ -394,17 +410,7 @@ std::string utils::convert_text(const std::string& text,
 
 std::string utils::get_command_output(const std::string& cmd)
 {
-	FILE* f = popen(cmd.c_str(), "r");
-	std::string buf;
-	if (f) {
-		char cbuf[1024];
-		size_t s;
-		while ((s = fread(cbuf, 1, sizeof(cbuf), f)) > 0) {
-			buf.append(cbuf, s);
-		}
-		pclose(f);
-	}
-	return buf;
+	return RustString(rs_get_command_output(cmd.c_str()));
 }
 
 void utils::extract_filter(const std::string& line,
@@ -416,7 +422,7 @@ void utils::extract_filter(const std::string& line,
 	filter = line.substr(pos + 1, pos1 - pos - 1);
 	pos = pos1;
 	url = line.substr(pos + 1, line.length() - pos);
-	LOG(level::DEBUG,
+	LOG(Level::DEBUG,
 		"utils::extract_filter: %s -> filter: %s url: %s",
 		line,
 		filter,
@@ -432,7 +438,7 @@ my_write_data(void* buffer, size_t size, size_t nmemb, void* userp)
 }
 
 std::string utils::retrieve_url(const std::string& url,
-	configcontainer* cfgcont,
+	ConfigContainer* cfgcont,
 	const std::string& authinfo,
 	const std::string* postdata,
 	CURL* cached_handle)
@@ -470,13 +476,13 @@ std::string utils::retrieve_url(const std::string& url,
 	}
 
 	if (postdata != nullptr) {
-		LOG(level::DEBUG,
+		LOG(Level::DEBUG,
 			"utils::retrieve_url(%s)[%s]: %s",
 			url,
 			postdata,
 			buf);
 	} else {
-		LOG(level::DEBUG, "utils::retrieve_url(%s)[-]: %s", url, buf);
+		LOG(Level::DEBUG, "utils::retrieve_url(%s)[-]: %s", url, buf);
 	}
 
 	return buf;
@@ -484,132 +490,24 @@ std::string utils::retrieve_url(const std::string& url,
 
 void utils::run_command(const std::string& cmd, const std::string& input)
 {
-	int rc = fork();
-	switch (rc) {
-	case -1:
-		break;
-	case 0: { // child:
-		int fd = ::open("/dev/null", O_RDWR);
-		if (fd == -1) {
-			LOG(level::DEBUG,
-				"utils::run_command: error opening /dev/null: "
-				"(%i) "
-				"%s",
-				errno,
-				strerror(errno));
-			exit(1);
-		}
-		close(0);
-		close(1);
-		close(2);
-		dup2(fd, 0);
-		dup2(fd, 1);
-		dup2(fd, 2);
-		LOG(level::DEBUG, "utils::run_command: %s '%s'", cmd, input);
-		execlp(cmd.c_str(), cmd.c_str(), input.c_str(), nullptr);
-		LOG(level::DEBUG,
-			"utils::run_command: execlp of %s failed: %s",
-			cmd,
-			strerror(errno));
-		exit(1);
-	}
-	default:
-		break;
-	}
+	rs_run_command(cmd.c_str(), input.c_str());
 }
 
 std::string utils::run_program(char* argv[], const std::string& input)
 {
-	std::string buf;
-	int ipipe[2];
-	int opipe[2];
-	if (pipe(ipipe) != 0) {
-		return "";
-	}
-	if (pipe(opipe) != 0) {
-		return "";
-	}
-
-	int rc = fork();
-	switch (rc) {
-	case -1:
-		break;
-	case 0: { // child:
-		close(ipipe[1]);
-		close(opipe[0]);
-		dup2(ipipe[0], 0);
-		dup2(opipe[1], 1);
-		close(2);
-
-		int errfd = ::open("/dev/null", O_WRONLY);
-		if (errfd != -1)
-			dup2(errfd, 2);
-
-		execvp(argv[0], argv);
-		exit(1);
-	}
-	default: {
-		close(ipipe[0]);
-		close(opipe[1]);
-		ssize_t written = 0;
-		written = write(ipipe[1], input.c_str(), input.length());
-		if (written != -1) {
-			close(ipipe[1]);
-			char cbuf[1024];
-			int rc2;
-			while ((rc2 = read(opipe[0], cbuf, sizeof(cbuf))) > 0) {
-				buf.append(cbuf, rc2);
-			}
-		} else {
-			close(ipipe[1]);
-		}
-		close(opipe[0]);
-	} break;
-	}
-	return buf;
+	return RustString(rs_run_program(argv, input.c_str()));
 }
 
 std::string utils::resolve_tilde(const std::string& str)
 {
-	const char* homedir;
-	std::string filepath;
-
-	if (!(homedir = ::getenv("HOME"))) {
-		struct passwd* spw = ::getpwuid(::getuid());
-		if (spw) {
-			homedir = spw->pw_dir;
-		} else {
-			homedir = "";
-		}
-	}
-
-	if (strcmp(homedir, "") != 0) {
-		if (str == "~") {
-			filepath.append(homedir);
-		} else if (str.substr(0, 2) == "~/") {
-			filepath.append(homedir);
-			filepath.append(1, '/');
-			filepath.append(str.substr(2, str.length() - 2));
-		} else {
-			filepath.append(str);
-		}
-	} else {
-		filepath.append(str);
-	}
-
-	return filepath;
+	return RustString(rs_resolve_tilde(str.c_str()));
 }
 
 std::string utils::replace_all(std::string str,
 	const std::string& from,
 	const std::string& to)
 {
-	std::string::size_type s = str.find(from);
-	while (s != std::string::npos) {
-		str.replace(s, from.length(), to);
-		s = str.find(from, s + to.length());
-	}
-	return str;
+	return RustString( rs_replace_all(str.c_str(), from.c_str(), to.c_str()) );
 }
 
 std::wstring utils::utf8str2wstr(const std::string& utf8str)
@@ -641,19 +539,10 @@ std::string utils::wstr2str(const std::wstring& wstr)
 
 std::string utils::absolute_url(const std::string& url, const std::string& link)
 {
-	xmlChar* newurl = xmlBuildURI(
-		(const xmlChar*)link.c_str(), (const xmlChar*)url.c_str());
-	std::string retval;
-	if (newurl) {
-		retval = (const char*)newurl;
-		xmlFree(newurl);
-	} else {
-		retval = link;
-	}
-	return retval;
+	return RustString(rs_absolute_url(url.c_str(), link.c_str()));
 }
 
-std::string utils::get_useragent(configcontainer* cfgcont)
+std::string utils::get_useragent(ConfigContainer* cfgcont)
 {
 	std::string ua_pref = cfgcont->get_configvalue("user-agent");
 	if (ua_pref.length() == 0) {
@@ -684,30 +573,24 @@ std::string utils::get_useragent(configcontainer* cfgcont)
 unsigned int utils::to_u(const std::string& str,
 	const unsigned int default_value)
 {
-	std::istringstream is(str);
-	unsigned int u;
-	is >> u;
-	if (is.fail() || !is.eof()) {
-		u = default_value;
-	}
-	return u;
+	return rs_to_u(str.c_str(), default_value);
 }
 
-scope_measure::scope_measure(const std::string& func, level ll)
+ScopeMeasure::ScopeMeasure(const std::string& func, Level ll)
 	: funcname(func)
 	, lvl(ll)
 {
 	gettimeofday(&tv1, nullptr);
 }
 
-void scope_measure::stopover(const std::string& son)
+void ScopeMeasure::stopover(const std::string& son)
 {
 	gettimeofday(&tv2, nullptr);
 	unsigned long diff =
 		(((tv2.tv_sec - tv1.tv_sec) * 1000000) + tv2.tv_usec) -
 		tv1.tv_usec;
 	LOG(lvl,
-		"scope_measure: function `%s' (stop over `%s') took %lu.%06lu "
+		"ScopeMeasure: function `%s' (stop over `%s') took %lu.%06lu "
 		"s so "
 		"far",
 		funcname,
@@ -716,115 +599,27 @@ void scope_measure::stopover(const std::string& son)
 		diff % 1000000);
 }
 
-scope_measure::~scope_measure()
+ScopeMeasure::~ScopeMeasure()
 {
 	gettimeofday(&tv2, nullptr);
 	unsigned long diff =
 		(((tv2.tv_sec - tv1.tv_sec) * 1000000) + tv2.tv_usec) -
 		tv1.tv_usec;
-	LOG(level::INFO,
-		"scope_measure: function `%s' took %lu.%06lu s",
+	LOG(Level::INFO,
+		"ScopeMeasure: function `%s' took %lu.%06lu s",
 		funcname,
 		diff / 1000000,
 		diff % 1000000);
 }
 
-void utils::append_escapes(std::string& str, char c)
-{
-	switch (c) {
-	case 'n':
-		str.append("\n");
-		break;
-	case 'r':
-		str.append("\r");
-		break;
-	case 't':
-		str.append("\t");
-		break;
-	case '"':
-		str.append("\"");
-		break;
-	// escaped backticks are passed through, still escaped. We un-escape
-	// them in configparser::evaluate_backticks
-	case '`':
-		str.append("\\`");
-		break;
-	case '\\':
-		break;
-	default:
-		str.append(1, c);
-		break;
-	}
-}
-
 bool utils::is_valid_color(const std::string& color)
 {
-	static const std::unordered_set<std::string> colors = {"black",
-		"red",
-		"green",
-		"yellow",
-		"blue",
-		"magenta",
-		"cyan",
-		"white",
-		"default"};
-	if (colors.find(color) != colors.end()) {
-		return true;
-	}
-
-	// does it start with "color"?
-	if (color.size() > 5 && color.substr(0, 5) == "color") {
-		if (color[5] == '0') {
-			// if the remainder of the string starts with zero, it
-			// can only be "color0"
-			return color == "color0" ? true : false;
-		} else {
-			// we're now sure that the remainder doesn't start with
-			// zero, but is it a valid decimal number?
-			const std::string number =
-				color.substr(5, color.size() - 5);
-			size_t pos{};
-			int n;
-			try {
-				n = std::stoi(number, &pos);
-			} catch (const std::invalid_argument& e) {
-				// What came after "color" wasn't a number,
-				// hence the input string is not a valid color.
-				return false;
-			} catch (const std::out_of_range& e) {
-				// What came after "color" couldn't fit into an
-				// int, whereas valid values all fit into a
-				// byte. Thus, the input string is not a valid
-				// color.
-				return false;
-			}
-
-			// remainder should not contain any trailing characters
-			if (number.size() != pos)
-				return false;
-
-			// remainder should be a number in (0; 255]. The
-			// interval is half-open because zero is already handled
-			// above.
-			if (n > 0 && n < 256)
-				return true;
-		}
-	}
-	return false;
+	return rs_is_valid_color(color.c_str());
 }
 
 bool utils::is_valid_attribute(const std::string& attrib)
 {
-	static const std::unordered_set<std::string> attribs = {"standout",
-		"underline",
-		"reverse",
-		"blink",
-		"dim",
-		"bold",
-		"protect",
-		"invis",
-		"default"};
-	return attribs.find(attrib) != attribs.end();
+	return rs_is_valid_attribute(attrib.c_str());
 }
 
 std::vector<std::pair<unsigned int, unsigned int>> utils::partition_indexes(
@@ -848,28 +643,12 @@ std::vector<std::pair<unsigned int, unsigned int>> utils::partition_indexes(
 
 size_t utils::strwidth(const std::string& str)
 {
-	std::wstring wstr = str2wstr(str);
-	int width = wcswidth(wstr.c_str(), wstr.length());
-	if (width < 1)                // a non-printable character found?
-		return wstr.length(); // return a sane width (which might be
-				      // larger than necessary)
-	return width;                 // exact width
+	return rs_strwidth(str.c_str());
 }
 
 size_t utils::strwidth_stfl(const std::string& str)
 {
-	size_t reduce_count = 0;
-	size_t len = str.length();
-	if (len > 1) {
-		for (size_t idx = 0; idx < len - 1; ++idx) {
-			if (str[idx] == '<' && str[idx + 1] != '>') {
-				reduce_count += 3;
-				idx += 3;
-			}
-		}
-	}
-
-	return strwidth(str) - reduce_count;
+	return rs_strwidth_stfl(str.c_str());
 }
 
 size_t utils::wcswidth_stfl(const std::wstring& str, size_t size)
@@ -887,7 +666,7 @@ size_t utils::wcswidth_stfl(const std::wstring& str, size_t size)
 
 	int width = wcswidth(str.c_str(), size);
 	if (width < 0) {
-		LOG(level::ERROR, "oh, oh, wcswidth just failed");
+		LOG(Level::ERROR, "oh, oh, wcswidth just failed");
 		return str.length() - reduce_count;
 	}
 
@@ -972,49 +751,32 @@ std::string utils::join(const std::vector<std::string>& strings,
 
 bool utils::is_special_url(const std::string& url)
 {
-	return is_query_url(url) || is_filter_url(url) || is_exec_url(url);
+	return rs_is_special_url(url.c_str());
 }
 
 bool utils::is_http_url(const std::string& url)
 {
-	return url.substr(0, 7) == "http://" || url.substr(0, 8) == "https://";
+	return rs_is_http_url(url.c_str());
 }
 
 bool utils::is_query_url(const std::string& url)
 {
-	return url.substr(0, 6) == "query:";
+	return rs_is_query_url(url.c_str());
 }
 
 bool utils::is_filter_url(const std::string& url)
 {
-	return url.substr(0, 7) == "filter:";
+	return rs_is_filter_url(url.c_str());
 }
 
 bool utils::is_exec_url(const std::string& url)
 {
-	return url.substr(0, 5) == "exec:";
+	return rs_is_exec_url(url.c_str());
 }
 
 std::string utils::censor_url(const std::string& url)
 {
-	std::string rv(url);
-	if (!url.empty() && !utils::is_special_url(url)) {
-		const char* myuri = url.c_str();
-		xmlURIPtr uri = xmlParseURI(myuri);
-		if (uri) {
-			if (uri->user) {
-				xmlFree(uri->user);
-				uri->user =
-					(char*)xmlStrdup((const xmlChar*)"*:*");
-			}
-			xmlChar* uristr = xmlSaveUri(uri);
-
-			rv = (const char*)uristr;
-			xmlFree(uristr);
-			xmlFreeURI(uri);
-		}
-	}
-	return rv;
+	return RustString(rs_censor_url(url.c_str()));
 }
 
 std::string utils::quote_for_stfl(std::string str)
@@ -1031,56 +793,30 @@ std::string utils::quote_for_stfl(std::string str)
 
 void utils::trim(std::string& str)
 {
-	while (str.length() > 0 && ::isspace(str[0])) {
-		str.erase(0, 1);
-	}
-	trim_end(str);
+	str = RustString(rs_trim(str.c_str()));
 }
 
 void utils::trim_end(std::string& str)
 {
-	std::string::size_type pos = str.length() - 1;
-	while (str.length() > 0 && (str[pos] == '\n' || str[pos] == '\r')) {
-		str.erase(pos);
-		pos--;
-	}
+	str = RustString(rs_trim_end(str.c_str()));
 }
 
 std::string utils::quote(const std::string& str)
 {
-	std::string rv = replace_all(str, "\"", "\\\"");
-	rv.insert(0, "\"");
-	rv.append("\"");
-	return rv;
+	return RustString(rs_quote(str.c_str()));
 }
 
 unsigned int utils::get_random_value(unsigned int max)
 {
-	static bool initialized = false;
-	if (!initialized) {
-		initialized = true;
-		srand(~(time(nullptr) ^ getpid() ^ getppid()));
-	}
-	// OpenBSD will warn you that rand() can be deterministic. We don't
-	// care, because this function is only used for simple things like
-	// selecting a random unread item.
-	return static_cast<unsigned int>(rand() % max);
+	return rs_get_random_value(max);
 }
 
 std::string utils::quote_if_necessary(const std::string& str)
 {
-	std::string result;
-	if (str.find_first_of(" ", 0) == std::string::npos) {
-		result = str;
-	} else {
-		result = utils::replace_all(str, "\"", "\\\"");
-		result.insert(0, "\"");
-		result.append("\"");
-	}
-	return result;
+	return RustString(rs_quote_if_necessary(str.c_str()));
 }
 
-void utils::set_common_curl_options(CURL* handle, configcontainer* cfg)
+void utils::set_common_curl_options(CURL* handle, ConfigContainer* cfg)
 {
 	if (cfg) {
 		if (cfg->get_configvalue_as_bool("use-proxy")) {
@@ -1105,7 +841,7 @@ void utils::set_common_curl_options(CURL* handle, configcontainer* cfg)
 			const std::string proxytype =
 				cfg->get_configvalue("proxy-type");
 			if (proxytype != "") {
-				LOG(level::DEBUG,
+				LOG(Level::DEBUG,
 					"utils::set_common_curl_options: "
 					"proxytype "
 					"= %s",
@@ -1168,6 +904,27 @@ std::string utils::get_content(xmlNode* node)
 	return retval;
 }
 
+std::string utils::get_basename(const std::string& url)
+{
+	std::string retval;
+	xmlURIPtr uri = xmlParseURI(url.c_str());
+	if (uri && uri->path) {
+		std::string path(uri->path);
+		// check for path ending with an empty filename
+		if (path[path.length() - 1] != '/') {
+			char* base = basename(uri->path);
+			if (base) {
+				// check for empty path
+				if (base[0] != '/') {
+					retval = std::string(base);
+				}
+			}
+		}
+		xmlFreeURI(uri);
+	}
+	return retval;
+}
+
 unsigned long utils::get_auth_method(const std::string& type)
 {
 	if (type == "any")
@@ -1190,7 +947,7 @@ unsigned long utils::get_auth_method(const std::string& type)
 	if (type == "anysafe")
 		return CURLAUTH_ANYSAFE;
 	if (type != "") {
-		LOG(level::USERERROR,
+		LOG(Level::USERERROR,
 			"you configured an invalid proxy authentication "
 			"method: %s",
 			type);
@@ -1214,39 +971,22 @@ curl_proxytype utils::get_proxy_type(const std::string& type)
 #endif
 
 	if (type != "") {
-		LOG(level::USERERROR,
+		LOG(Level::USERERROR,
 			"you configured an invalid proxy type: %s",
 			type);
 	}
 	return CURLPROXY_HTTP;
 }
 
-std::string utils::escape_url(const std::string& url)
-{
-	CURL* easyhandle = curl_easy_init();
-	char* output = curl_easy_escape(easyhandle, url.c_str(), 0);
-	if (!output) {
-		LOG(level::DEBUG, "Libcurl failed to escape url: %s", url);
-		throw std::runtime_error("escaping url failed");
-	}
-	std::string s = output;
-	curl_free(output);
-	curl_easy_cleanup(easyhandle);
-	return s;
-}
-
 std::string utils::unescape_url(const std::string& url)
 {
-	CURL* easyhandle = curl_easy_init();
-	char* output = curl_easy_unescape(easyhandle, url.c_str(), 0, NULL);
-	if (!output) {
-		LOG(level::DEBUG, "Libcurl failed to escape url: %s", url);
-		throw std::runtime_error("escaping url failed");
+	char* ptr = rs_unescape_url(url.c_str());
+	if (ptr == nullptr) {
+		LOG(Level::DEBUG, "Rust failed to unescape url: %s", url );
+		throw std::runtime_error("unescaping url failed");
+	} else {
+		return RustString(ptr);
 	}
-	std::string s = output;
-	curl_free(output);
-	curl_easy_cleanup(easyhandle);
-	return s;
 }
 
 std::wstring utils::clean_nonprintable_characters(std::wstring text)
@@ -1310,59 +1050,22 @@ int utils::mkdir_parents(const std::string& p, mode_t mode)
 
 std::string utils::make_title(const std::string& const_url)
 {
-	/* Sometimes it is possible to construct the title from the URL
-	 * This attempts to do just that. eg:
-	 * http://domain.com/story/yy/mm/dd/title-with-dashes?a=b
-	 */
-	std::string url = (std::string&)const_url;
-	// Strip out trailing slashes
-	while (url.length() > 0 && url.back() == '/') {
-		url.erase(url.length() - 1);
-	}
-	// get to the final part of the URI's path
-	std::string::size_type pos_of_slash = url.find_last_of('/');
-	// extract just the juicy part 'title-with-dashes?a=b'
-	std::string path = url.substr(pos_of_slash + 1);
-	// find where query part of URI starts
-	std::string::size_type pos_of_qmrk = path.find_first_of('?');
-	// throw away the query part 'title-with-dashes'
-	std::string title = path.substr(0, pos_of_qmrk);
-	// Throw away common webpage suffixes: .html, .php, .aspx, .htm
-	std::regex rx("\\.html$|\\.htm$|\\.php$|\\.aspx$");
-	title = std::regex_replace(title, rx, "");
-	// if there is nothing left, just give up
-	if (title.empty())
-		return title;
-	// 'title with dashes'
-	std::replace(title.begin(), title.end(), '-', ' ');
-	std::replace(title.begin(), title.end(), '_', ' ');
-	//'Title with dashes'
-	if (title.at(0) >= 'a' && title.at(0) <= 'z') {
-		title[0] -= 'a' - 'A';
-	}
-	// Un-escape any percent-encoding, e.g. "It%27s%202017%21" -> "It's
-	// 2017!"
-	auto const result = xmlURIUnescapeString(title.c_str(), 0, nullptr);
-	if (result) {
-		title = result;
-		xmlFree(result);
-	}
-	return title;
+	return RustString(rs_make_title(const_url.c_str()));
 }
 
 int utils::run_interactively(const std::string& command,
 	const std::string& caller)
 {
-	LOG(level::DEBUG, "%s: running `%s'", caller, command);
+	LOG(Level::DEBUG, "%s: running `%s'", caller, command);
 
 	int status = ::system(command.c_str());
 
 	if (status == -1) {
-		LOG(level::DEBUG,
+		LOG(Level::DEBUG,
 			"%s: couldn't create a child process",
 			caller);
 	} else if (status == 127) {
-		LOG(level::DEBUG, "%s: couldn't run shell", caller);
+		LOG(Level::DEBUG, "%s: couldn't run shell", caller);
 	}
 
 	return status;
@@ -1406,16 +1109,7 @@ void utils::remove_soft_hyphens(std::string& text)
 
 bool utils::is_valid_podcast_type(const std::string& mimetype)
 {
-	const std::regex acceptable_rx{"(audio|video)/.*",
-		std::regex_constants::ECMAScript |
-			std::regex_constants::optimize};
-
-	const std::unordered_set<std::string> acceptable = {"application/ogg"};
-
-	const bool found = acceptable.find(mimetype) != acceptable.end();
-	const bool matches = std::regex_match(mimetype, acceptable_rx);
-
-	return found || matches;
+	return rs_is_valid_podcast_type(mimetype.c_str());
 }
 
 	/*
@@ -1435,7 +1129,7 @@ static void
 openssl_mth_locking_function(int mode, int n, const char* file, int line)
 {
 	if (n < 0 || n >= openssl_mutexes_size) {
-		LOG(level::ERROR,
+		LOG(Level::ERROR,
 			"openssl_mth_locking_function: index is out of bounds "
 			"(called by %s:%d)",
 			file,
@@ -1443,10 +1137,10 @@ openssl_mth_locking_function(int mode, int n, const char* file, int line)
 		return;
 	}
 	if (mode & CRYPTO_LOCK) {
-		LOG(level::DEBUG, "OpenSSL lock %d: %s:%d", n, file, line);
+		LOG(Level::DEBUG, "OpenSSL lock %d: %s:%d", n, file, line);
 		openssl_mutexes[n].lock();
 	} else {
-		LOG(level::DEBUG, "OpenSSL unlock %d: %s:%d", n, file, line);
+		LOG(Level::DEBUG, "OpenSSL unlock %d: %s:%d", n, file, line);
 		openssl_mutexes[n].unlock();
 	}
 }
@@ -1472,4 +1166,9 @@ void utils::initialize_ssl_implementation(void)
 #endif
 }
 
+std::string utils::get_default_browser()
+{
+	return RustString(rs_get_default_browser());
+}
+
 } // namespace newsboat
