@@ -4,17 +4,17 @@
 
 #include "3rd-party/catch.hpp"
 #include "configcontainer.h"
-#include "rss_parser.h"
+#include "rssparser.h"
 #include "test-helpers.h"
 
 using namespace newsboat;
 
-TEST_CASE("items in search result can be marked read", "[cache]")
+TEST_CASE("items in search result can be marked read", "[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
-	rss_parser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
+	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache.externalize_rssfeed(feed, false);
 
@@ -32,19 +32,19 @@ TEST_CASE("items in search result can be marked read", "[cache]")
 	REQUIRE_FALSE(updatedItem->unread());
 }
 
-TEST_CASE("Cleaning old articles works", "[cache]")
+TEST_CASE("Cleaning old articles works", "[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	std::unique_ptr<configcontainer> cfg(new configcontainer());
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), cfg.get()));
-	rss_parser parser(
+	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), cfg.get()));
+	RssParser parser(
 		"file://data/rss.xml", rsscache.get(), cfg.get(), nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	/* Adding a fresh item that won't be deleted. If it survives the test,
 	 * we will know that "keep-articles-days" really deletes the old
 	 * articles *only* and not the whole database. */
-	auto item = std::make_shared<rss_item>(rsscache.get());
+	auto item = std::make_shared<RssItem>(rsscache.get());
 	item->set_title("Test item");
 	item->set_link("http://example.com/item");
 	item->set_guid("http://example.com/item");
@@ -59,27 +59,27 @@ TEST_CASE("Cleaning old articles works", "[cache]")
 	/* Simulating a restart of Newsboat. */
 
 	/* Setting "keep-articles-days" to non-zero value to trigger
-	 * cache::clean_old_articles().
+	 * Cache::clean_old_articles().
 	 *
 	 * The value of 42 days is sufficient because the items in the test feed
 	 * are dating back to 2006. */
-	cfg.reset(new configcontainer());
+	cfg.reset(new ConfigContainer());
 	cfg->set_configvalue("keep-articles-days", "42");
-	rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+	rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	/* The important part: old articles should be gone, new one remains. */
 	REQUIRE(feed->items().size() == 1);
 }
 
-TEST_CASE("Last-Modified and ETag values are persisted to DB", "[cache]")
+TEST_CASE("Last-Modified and ETag values are persisted to DB", "[Cache]")
 {
-	std::unique_ptr<configcontainer> cfg(new configcontainer());
+	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
 	TestHelpers::TempFile dbfile;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), cfg.get()));
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), cfg.get()));
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	rsscache->externalize_rssfeed(feed, false);
 
 	/* We will run this lambda on different inputs to check different
@@ -91,8 +91,8 @@ TEST_CASE("Last-Modified and ETag values are persisted to DB", "[cache]")
 		REQUIRE_NOTHROW(rsscache->update_lastmodified(
 			feedurl, last_modified, etag));
 
-		cfg.reset(new configcontainer());
-		rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+		cfg.reset(new ConfigContainer());
+		rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 
 		/* Scrambling the value to make sure the following call changes
 		 * it. */
@@ -125,14 +125,14 @@ TEST_CASE("Last-Modified and ETag values are persisted to DB", "[cache]")
 	}
 }
 
-TEST_CASE("mark_all_read marks all items in the feed read", "[cache]")
+TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 {
-	std::shared_ptr<rss_feed> feed, test_feed;
+	std::shared_ptr<RssFeed> feed, test_feed;
 
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 
-	test_feed = std::make_shared<rss_feed>(&rsscache);
+	test_feed = std::make_shared<RssFeed>(&rsscache);
 	test_feed->set_title("Test feed");
 	auto test_feed_url = "http://example.com/atom.xml";
 	test_feed->set_link(test_feed_url);
@@ -143,9 +143,9 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[cache]")
 		{"file://data/atom10_1.xml", 3}};
 
 	/* Ensure that the feeds contain expected number of items, then
-	 * externalize them (put into cache). */
+	 * externalize them (put into Cache). */
 	for (const auto& feed_data : feeds) {
-		rss_parser parser(feed_data.first, &rsscache, &cfg, nullptr);
+		RssParser parser(feed_data.first, &rsscache, &cfg, nullptr);
 		feed = parser.parse();
 		REQUIRE(feed->total_item_count() == feed_data.second);
 
@@ -196,7 +196,7 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[cache]")
 
 		/* Since test_feed contains the first item of each feed, only
 		 * these two items should be marked read. */
-		auto unread_items_count = [](std::shared_ptr<rss_feed>& feed) {
+		auto unread_items_count = [](std::shared_ptr<RssFeed>& feed) {
 			unsigned int count = 0;
 			for (const auto& item : feed->items()) {
 				if (item->unread()) {
@@ -234,19 +234,19 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[cache]")
 TEST_CASE(
 	"cleanup_cache is controlled by `cleanup-on-quit` "
 	"and `delete-read-articles-on-quit` settings",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
 
 	std::vector<std::string> feedurls = {
 		"file://data/rss.xml", "file://data/atom10_1.xml"};
 
-	std::vector<std::shared_ptr<rss_feed>> feeds;
-	std::unique_ptr<configcontainer> cfg(new configcontainer());
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), cfg.get()));
+	std::vector<std::shared_ptr<RssFeed>> feeds;
+	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), cfg.get()));
 	for (const auto& url : feedurls) {
-		rss_parser parser(url, rsscache.get(), cfg.get(), nullptr);
-		std::shared_ptr<rss_feed> feed = parser.parse();
+		RssParser parser(url, rsscache.get(), cfg.get(), nullptr);
+		std::shared_ptr<RssFeed> feed = parser.parse();
 		feeds.push_back(feed);
 		rsscache->externalize_rssfeed(feed, false);
 	}
@@ -256,11 +256,11 @@ TEST_CASE(
 		cfg->set_configvalue("cleanup-on-quit", "no");
 		rsscache->cleanup_cache(feeds);
 
-		cfg.reset(new configcontainer());
-		rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+		cfg.reset(new ConfigContainer());
+		rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 
 		for (const auto& url : feedurls) {
-			std::shared_ptr<rss_feed> feed =
+			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(url, nullptr);
 			REQUIRE(feed->total_item_count() != 0);
 		}
@@ -273,14 +273,14 @@ TEST_CASE(
 		SECTION("delete-read-articles-on-quit set to \"no\"")
 		{
 			/* Drop first feed; it should now be removed from the
-			 * cache, too. */
+			 * Cache, too. */
 			feeds.erase(feeds.cbegin(), feeds.cbegin() + 1);
 			rsscache->cleanup_cache(feeds);
 
-			cfg.reset(new configcontainer());
-			rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+			cfg.reset(new ConfigContainer());
+			rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 
-			std::shared_ptr<rss_feed> feed =
+			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
 					feedurls[0], nullptr);
 			REQUIRE(feed->total_item_count() == 0);
@@ -299,10 +299,10 @@ TEST_CASE(
 
 			rsscache->cleanup_cache(feeds);
 
-			cfg.reset(new configcontainer());
-			rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+			cfg.reset(new ConfigContainer());
+			rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 
-			std::shared_ptr<rss_feed> feed =
+			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
 					feedurls[0], nullptr);
 			REQUIRE(feed->total_item_count() == 6);
@@ -310,13 +310,13 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[cache]")
+TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, &rsscache, &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	rsscache.externalize_rssfeed(feed, false);
 
@@ -331,14 +331,14 @@ TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[cache]")
 	}
 }
 
-TEST_CASE("get_unread_count returns number of yet unread articles", "[cache]")
+TEST_CASE("get_unread_count returns number of yet unread articles", "[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
-	std::unique_ptr<rss_parser> parser(new rss_parser(
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
+	std::unique_ptr<RssParser> parser(new RssParser(
 		"file://data/rss.xml", rsscache.get(), &cfg, nullptr));
-	std::shared_ptr<rss_feed> feed = parser->parse();
+	std::shared_ptr<RssFeed> feed = parser->parse();
 	// Marking one article as read to make sure get_unread_count() really
 	// counts only unread articles
 	feed->items()[0]->set_unread(false);
@@ -348,7 +348,7 @@ TEST_CASE("get_unread_count returns number of yet unread articles", "[cache]")
 
 	// Let's add another article to make sure get_unread_count looks at all
 	// feeds present in the cache
-	parser.reset(new rss_parser(
+	parser.reset(new RssParser(
 		"file://data/atom10_1.xml", rsscache.get(), &cfg, nullptr));
 	feed = parser->parse();
 	feed->items()[0]->set_unread(false);
@@ -357,25 +357,25 @@ TEST_CASE("get_unread_count returns number of yet unread articles", "[cache]")
 	REQUIRE(rsscache->get_unread_count() == 8);
 
 	// Lastly, let's make sure the info is indeed retrieved from the
-	// database and isn't just stored in the cache object
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
+	// database and isn't just stored in the Cache object
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 	REQUIRE(rsscache->get_unread_count() == 8);
 }
 
 TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 
 	// We'll keep our own count of which GUIDs are unread
 	std::unordered_set<std::string> read_guids;
-	std::unique_ptr<rss_parser> parser(new rss_parser(
+	std::unique_ptr<RssParser> parser(new RssParser(
 		"file://data/rss.xml", rsscache.get(), &cfg, nullptr));
-	std::shared_ptr<rss_feed> feed = parser->parse();
+	std::shared_ptr<RssFeed> feed = parser->parse();
 
-	auto mark_read = [&read_guids](std::shared_ptr<rss_item> item) {
+	auto mark_read = [&read_guids](std::shared_ptr<RssItem> item) {
 		item->set_unread(false);
 		INFO("add  " + item->guid());
 		read_guids.insert(item->guid());
@@ -404,8 +404,8 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 	check(rsscache->get_read_item_guids());
 
 	// Let's add another article to make sure get_unread_count looks at all
-	// feeds present in the cache
-	parser.reset(new rss_parser(
+	// feeds present in the Cache
+	parser.reset(new RssParser(
 		"file://data/atom10_1.xml", rsscache.get(), &cfg, nullptr));
 	feed = parser->parse();
 	mark_read(feed->items()[0]);
@@ -416,21 +416,21 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 	check(rsscache->get_read_item_guids());
 
 	// Lastly, let's make sure the info is indeed retrieved from the
-	// database and isn't just stored in the cache object
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
-	INFO("Testing on two feeds with new `cache` object");
+	// database and isn't just stored in the Cache object
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
+	INFO("Testing on two feeds with new `Cache` object");
 	check(rsscache->get_read_item_guids());
 }
 
 TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	auto item = feed->items()[1];
 	auto guid = item->guid();
@@ -438,21 +438,21 @@ TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 	rsscache->externalize_rssfeed(feed, false);
 	rsscache->mark_item_deleted(guid, true);
 
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	// One item was deleted, so shouldn't have been loaded
 	REQUIRE(feed->total_item_count() == 7);
 }
 
 TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	REQUIRE(feed->unread_item_count() == 8);
 
@@ -462,7 +462,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid({}));
 
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 8);
 	}
@@ -475,7 +475,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid(guids));
 
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 6);
 	}
@@ -484,13 +484,13 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 TEST_CASE(
 	"remove_old_deleted_items removes deleted items with particular "
 	"feedurl if its GUID is not in the vector",
-	"[cache]")
+	"[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, &rsscache, &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	REQUIRE(feed->total_item_count() == 8);
 
@@ -525,21 +525,21 @@ TEST_CASE(
 }
 
 TEST_CASE("search_for_items finds all items with matching title or content",
-	"[cache]")
+	"[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	std::vector<std::string> feedurls = {
 		"file://data/atom10_1.xml", "file://data/rss20_1.xml"};
 	for (const auto& url : feedurls) {
-		rss_parser parser(url, &rsscache, &cfg, nullptr);
-		std::shared_ptr<rss_feed> feed = parser.parse();
+		RssParser parser(url, &rsscache, &cfg, nullptr);
+		std::shared_ptr<RssFeed> feed = parser.parse();
 
 		rsscache.externalize_rssfeed(feed, false);
 	}
 
 	auto query = "content";
-	std::vector<std::shared_ptr<rss_item>> items;
+	std::vector<std::shared_ptr<RssItem>> items;
 
 	SECTION("Search the whole DB")
 	{
@@ -560,21 +560,21 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 }
 
 TEST_CASE("update_rssitem_flags dumps `rss_item` object's flags to DB",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	rsscache->externalize_rssfeed(feed, false);
 
 	auto item = feed->items()[0];
 	item->set_flags("abc");
 	REQUIRE_NOTHROW(rsscache->update_rssitem_flags(item.get()));
 
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	REQUIRE(feed->items()[0]->flags() == "abc");
@@ -583,14 +583,14 @@ TEST_CASE("update_rssitem_flags dumps `rss_item` object's flags to DB",
 TEST_CASE(
 	"update_rssitem_unread_and_enqueued updates item's \"unread\" and "
 	"\"enqueued\" fields",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 
 	auto item = feed->items()[0];
 
@@ -603,7 +603,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 			item, feedurl));
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -616,7 +616,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 			item, feedurl));
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE(feed->items()[0]->enqueued());
@@ -631,7 +631,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 			item, feedurl));
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -642,10 +642,10 @@ TEST_CASE(
 TEST_CASE(
 	"{externalize,internalize}_rssfeed puts a feed into DB and gets it "
 	"back",
-	"[cache]")
+	"[Cache]")
 {
-	auto feeds_are_the_same = [](const std::shared_ptr<rss_feed>& feed1,
-					  const std::shared_ptr<rss_feed>&
+	auto feeds_are_the_same = [](const std::shared_ptr<RssFeed>& feed1,
+					  const std::shared_ptr<RssFeed>&
 						  feed2) {
 		REQUIRE(feed1->title_raw() == feed2->title_raw());
 		REQUIRE(feed1->title() == feed2->title());
@@ -695,10 +695,10 @@ TEST_CASE(
 	};
 
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
 	auto initial_feed = parser.parse();
 	initial_feed->load();
 	initial_feed->unload();
@@ -708,7 +708,7 @@ TEST_CASE(
 	{
 		rsscache->externalize_rssfeed(initial_feed, false);
 
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -721,7 +721,7 @@ TEST_CASE(
 		rsscache->externalize_rssfeed(initial_feed, false);
 		rsscache->externalize_rssfeed(initial_feed, false);
 
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -730,41 +730,41 @@ TEST_CASE(
 }
 
 TEST_CASE("externalize_rssfeed doesn't store more than `max-items` items",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	std::unique_ptr<configcontainer> cfg(new configcontainer());
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), cfg.get()));
+	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), cfg.get()));
 
 	cfg->set_configvalue("max-items", "3");
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
+	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
 	auto feed = parser.parse();
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache->externalize_rssfeed(feed, false);
 
-	cfg.reset(new configcontainer());
-	rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+	cfg.reset(new ConfigContainer());
+	rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	REQUIRE(feed->total_item_count() == 3);
 }
 
 TEST_CASE("externalize_rssfeed does nothing if it's passed a query feed",
-	"[cache]")
+	"[Cache]")
 {
 }
 
 TEST_CASE(
 	"internalize_rssfeed doesn't return more than `max-items` items, "
 	"not counting the flagged ones",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	std::unique_ptr<configcontainer> cfg(new configcontainer());
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), cfg.get()));
+	std::unique_ptr<ConfigContainer> cfg(new ConfigContainer());
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), cfg.get()));
 
 	const auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
+	RssParser parser(feedurl, rsscache.get(), cfg.get(), nullptr);
 	auto feed = parser.parse();
 	REQUIRE(feed->total_item_count() == 8);
 
@@ -772,9 +772,9 @@ TEST_CASE(
 	{
 		rsscache->externalize_rssfeed(feed, false);
 
-		cfg.reset(new configcontainer());
+		cfg.reset(new ConfigContainer());
 		cfg->set_configvalue("max-items", "3");
-		rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+		rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->total_item_count() == 3);
 	}
@@ -787,9 +787,9 @@ TEST_CASE(
 		rsscache->update_rssitem_flags(feed->items()[0].get());
 		rsscache->update_rssitem_flags(feed->items()[1].get());
 
-		cfg.reset(new configcontainer());
+		cfg.reset(new ConfigContainer());
 		cfg->set_configvalue("max-items", "1");
-		rsscache.reset(new cache(dbfile.getPath(), cfg.get()));
+		rsscache.reset(new Cache(dbfile.getPath(), cfg.get()));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		// All flagged items should be present no matter what
 		unsigned int flagged_count = 0;
@@ -804,10 +804,10 @@ TEST_CASE(
 
 TEST_CASE(
 	"internalize_rssfeed returns feed without items but specified RSS URL",
-	"[cache]")
+	"[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	auto feedurl = "query:misc:age between 0:10";
 	auto feed = rsscache.internalize_rssfeed(feedurl, nullptr);
 
@@ -816,18 +816,18 @@ TEST_CASE(
 }
 
 TEST_CASE("internalize_rssfeed doesn't return items that are ignored",
-	"[cache]")
+	"[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 
 	const std::string feedurl("file://data/rss092_1.xml");
-	rss_parser parser(feedurl, &rsscache, &cfg, nullptr);
+	RssParser parser(feedurl, &rsscache, &cfg, nullptr);
 	auto feed = parser.parse();
 	REQUIRE(feed->total_item_count() == 3);
 	rsscache.externalize_rssfeed(feed, false);
 
-	rss_ignores ign;
+	RssIgnores ign;
 	ign.handle_action("ignore-article", {"*", "title =~ \"third\""});
 
 	feed = rsscache.internalize_rssfeed(feedurl, nullptr);
@@ -839,18 +839,18 @@ TEST_CASE("internalize_rssfeed doesn't return items that are ignored",
 TEST_CASE(
 	"externalize_rssfeed resets \"unread\" field if item's content "
 	"changed and reset_unread = \"yes\"",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(feed, false);
 
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	feed->load();
 	REQUIRE_FALSE(feed->items()[0]->unread());
@@ -860,7 +860,7 @@ TEST_CASE(
 	SECTION("reset_unread = false; item remains read")
 	{
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
@@ -868,7 +868,7 @@ TEST_CASE(
 	SECTION("reset_unread = true; item becomes unread")
 	{
 		rsscache->externalize_rssfeed(feed, true);
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -877,18 +877,18 @@ TEST_CASE(
 TEST_CASE(
 	"externalize_rssfeed only updates \"unread\" field if override_unread "
 	"is set",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 	auto feedurl = "file://data/rss.xml";
-	rss_parser parser(feedurl, rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	RssParser parser(feedurl, rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(feed, false);
 
-	rsscache.reset(new cache(dbfile.getPath(), &cfg));
+	rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	auto item = feed->items()[0];
 	item->set_unread_nowrite(true);
@@ -896,7 +896,7 @@ TEST_CASE(
 	SECTION("override_unread not set; item remains read")
 	{
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
@@ -905,7 +905,7 @@ TEST_CASE(
 	{
 		item->set_override_unread(true);
 		rsscache->externalize_rssfeed(feed, false);
-		rsscache.reset(new cache(dbfile.getPath(), &cfg));
+		rsscache.reset(new Cache(dbfile.getPath(), &cfg));
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -914,19 +914,19 @@ TEST_CASE(
 TEST_CASE(
 	"externalize_rssfeed does not create an entry in rss_feed table "
 	"when passed a query feed",
-	"[cache]")
+	"[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
 
-	auto feed = std::make_shared<rss_feed>(rsscache.get());
+	auto feed = std::make_shared<RssFeed>(rsscache.get());
 	feed->set_query("unread = \"yes\"");
 	feed->set_rssurl("query:All unread:unread = \"yes\"");
 
 	REQUIRE_NOTHROW(rsscache->externalize_rssfeed(feed, false));
 
-	// Getting rid of `cache` instance to make sure it doesn't hold the
+	// Getting rid of `Cache` instance to make sure it doesn't hold the
 	// database anymore and did everything it wanted to
 	rsscache.reset();
 
@@ -966,32 +966,32 @@ TEST_CASE(
 		db.get(), query.c_str(), count_callback, &count, &errors);
 	REQUIRE(rc == SQLITE_OK);
 
-	INFO("There should be no feeds in the cache");
+	INFO("There should be no feeds in the Cache");
 	REQUIRE(count == 0);
 }
 
-TEST_CASE("do_vacuum doesn't throw an exception", "[cache]")
+TEST_CASE("do_vacuum doesn't throw an exception", "[Cache]")
 {
 	TestHelpers::TempFile dbfile;
-	configcontainer cfg;
-	std::unique_ptr<cache> rsscache(new cache(dbfile.getPath(), &cfg));
-	rss_parser parser("file://data/rss.xml", rsscache.get(), &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	ConfigContainer cfg;
+	std::unique_ptr<Cache> rsscache(new Cache(dbfile.getPath(), &cfg));
+	RssParser parser("file://data/rss.xml", rsscache.get(), &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	rsscache->externalize_rssfeed(feed, false);
 
 	REQUIRE_NOTHROW(rsscache->do_vacuum());
 
-	// Checking that cache can still be opened
-	REQUIRE_NOTHROW(rsscache.reset(new cache(dbfile.getPath(), &cfg)));
+	// Checking that Cache can still be opened
+	REQUIRE_NOTHROW(rsscache.reset(new Cache(dbfile.getPath(), &cfg)));
 }
 
 TEST_CASE("search_in_items returns items that contain given substring",
-	"[cache]")
+	"[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
-	rss_parser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
+	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	REQUIRE(feed->total_item_count() == 8);
 	rsscache.externalize_rssfeed(feed, false);
 
@@ -1034,12 +1034,12 @@ TEST_CASE("search_in_items returns items that contain given substring",
 	}
 }
 
-TEST_CASE("search_in_items returns empty set if input set is empty", "[cache]")
+TEST_CASE("search_in_items returns empty set if input set is empty", "[Cache]")
 {
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
-	rss_parser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
-	std::shared_ptr<rss_feed> feed = parser.parse();
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
+	RssParser parser("file://data/rss.xml", &rsscache, &cfg, nullptr);
+	std::shared_ptr<RssFeed> feed = parser.parse();
 	rsscache.externalize_rssfeed(feed, false);
 
 	using guids = std::unordered_set<std::string>;
