@@ -7,12 +7,12 @@
 
 using namespace newsboat;
 
-TEST_CASE("Parses test config without exceptions", "[configcontainer]")
+TEST_CASE("Parses test config without exceptions", "[ConfigContainer]")
 {
-	configcontainer cfg;
-	configparser cfgparser;
+	ConfigContainer cfg;
+	ConfigParser cfgparser;
 	cfg.register_commands(cfgparser);
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 	cfgparser.register_handler("macro", &k);
 
 	REQUIRE_NOTHROW(cfgparser.parse("data/test-config.txt"));
@@ -44,10 +44,10 @@ TEST_CASE("Parses test config without exceptions", "[configcontainer]")
 
 TEST_CASE(
 	"Parses test config correctly, even if there's no \\n at the end line.",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
-	configparser cfgparser;
+	ConfigContainer cfg;
+	ConfigParser cfgparser;
 	cfg.register_commands(cfgparser);
 
 	REQUIRE_NOTHROW(cfgparser.parse(
@@ -64,52 +64,52 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("Throws if invalid command is encountered", "[configcontainer]")
+TEST_CASE("Throws if invalid command is encountered", "[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	CHECK_THROWS_AS(cfg.handle_action("command-that-surely-does-not-exist",
 				{"and", "its", "arguments"}),
-		confighandlerexception);
+		ConfigHandlerException);
 }
 
-TEST_CASE("Throws if there are no arguments", "[configcontainer]")
+TEST_CASE("Throws if there are no arguments", "[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	CHECK_THROWS_AS(
-		cfg.handle_action("auto-reload", {}), confighandlerexception);
+		cfg.handle_action("auto-reload", {}), ConfigHandlerException);
 }
 
-TEST_CASE("Throws if command argument has invalid type", "[configcontainer]")
+TEST_CASE("Throws if command argument has invalid type", "[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	SECTION("bool")
 	{
 		CHECK_THROWS_AS(cfg.handle_action("always-display-description",
 					{"whatever"}),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 
 	SECTION("int")
 	{
 		CHECK_THROWS_AS(
 			cfg.handle_action("download-retries", {"whatever"}),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 
 	SECTION("enum")
 	{
 		CHECK_THROWS_AS(cfg.handle_action("proxy-type", {"whatever"}),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 }
 
 TEST_CASE("reset_to_default changes setting to its default value",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	const std::string default_value = "any";
 	const std::vector<std::string> tests{"any",
@@ -132,9 +132,9 @@ TEST_CASE("reset_to_default changes setting to its default value",
 }
 
 TEST_CASE("get_configvalue_as_bool() recognizes several boolean formats",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 	cfg.set_configvalue("cleanup-on-quit", "yes");
 	cfg.set_configvalue("auto-reload", "true");
 	cfg.set_configvalue("show-read-feeds", "no");
@@ -161,9 +161,9 @@ TEST_CASE("get_configvalue_as_bool() recognizes several boolean formats",
 }
 
 TEST_CASE("toggle() inverts the value of a boolean setting",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	const std::string key("always-display-description");
 	SECTION("\"true\" becomes \"false\"")
@@ -182,9 +182,9 @@ TEST_CASE("toggle() inverts the value of a boolean setting",
 }
 
 TEST_CASE("toggle() does nothing if setting is non-boolean",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	const std::vector<std::string> tests{"articlelist-title-format",
 		"cache-file",
@@ -205,9 +205,9 @@ TEST_CASE("toggle() does nothing if setting is non-boolean",
 TEST_CASE(
 	"dump_config turns current state into text and saves it "
 	"into the supplyed vector",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	auto all_values_found =
 		[](std::unordered_set<std::string>& expected,
@@ -266,9 +266,9 @@ TEST_CASE(
 TEST_CASE(
 	"get_suggestions() returns all settings whose names begin "
 	"with a given string",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	const std::string key1("d");
 	const std::unordered_set<std::string> expected1{
@@ -277,6 +277,7 @@ TEST_CASE(
 		"dialogs-title-format",
 		"display-article-progress",
 		"download-full-page",
+		"download-filename-format",
 		"download-path",
 		"download-retries",
 		"download-timeout",
@@ -308,9 +309,9 @@ TEST_CASE(
 }
 
 TEST_CASE("get_suggestions() returns results in alphabetical order",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 
 	const std::vector<std::string> keys{"dow", "rel", "us", "d"};
 	for (const auto& key : keys) {
@@ -329,81 +330,81 @@ TEST_CASE("get_suggestions() returns results in alphabetical order",
 TEST_CASE(
 	"get_feed_sort_strategy() returns correctly filled FeedSortStrategy "
 	"struct",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 	FeedSortStrategy sort_strategy;
 
 	SECTION("none")
 	{
 		cfg.set_configvalue("feed-sort-order", "none");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::NONE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::NONE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "none-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::NONE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::NONE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "none-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::NONE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::NONE);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 
 	SECTION("firsttag")
 	{
 		cfg.set_configvalue("feed-sort-order", "firsttag");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::FIRST_TAG);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::FIRST_TAG);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "firsttag-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::FIRST_TAG);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::FIRST_TAG);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "firsttag-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::FIRST_TAG);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::FIRST_TAG);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 
 	SECTION("title")
 	{
 		cfg.set_configvalue("feed-sort-order", "title");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "title-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "title-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 
 	SECTION("articlecount")
 	{
 		cfg.set_configvalue("feed-sort-order", "articlecount");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "articlecount-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "articlecount-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 
 	SECTION("unreadarticlecount")
@@ -411,156 +412,156 @@ TEST_CASE(
 		cfg.set_configvalue("feed-sort-order", "unreadarticlecount");
 		sort_strategy = cfg.get_feed_sort_strategy();
 		REQUIRE(sort_strategy.sm ==
-			feed_sort_method_t::UNREAD_ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+			FeedSortMethod::UNREAD_ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue(
 			"feed-sort-order", "unreadarticlecount-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
 		REQUIRE(sort_strategy.sm ==
-			feed_sort_method_t::UNREAD_ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+			FeedSortMethod::UNREAD_ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue(
 			"feed-sort-order", "unreadarticlecount-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
 		REQUIRE(sort_strategy.sm ==
-			feed_sort_method_t::UNREAD_ARTICLE_COUNT);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+			FeedSortMethod::UNREAD_ARTICLE_COUNT);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 
 	SECTION("lastupdated")
 	{
 		cfg.set_configvalue("feed-sort-order", "lastupdated");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::LAST_UPDATED);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::LAST_UPDATED);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "lastupdated-desc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::LAST_UPDATED);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::LAST_UPDATED);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("feed-sort-order", "lastupdated-asc");
 		sort_strategy = cfg.get_feed_sort_strategy();
-		REQUIRE(sort_strategy.sm == feed_sort_method_t::LAST_UPDATED);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == FeedSortMethod::LAST_UPDATED);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 	}
 }
 
 TEST_CASE(
 	"get_article_sort_strategy() returns correctly filled "
 	"ArticleSortStrategy struct",
-	"[configcontainer]")
+	"[ConfigContainer]")
 {
-	configcontainer cfg;
+	ConfigContainer cfg;
 	ArticleSortStrategy sort_strategy;
 
 	SECTION("title")
 	{
 		cfg.set_configvalue("article-sort-order", "title");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "title-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "title-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::TITLE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::TITLE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 
 	SECTION("flags")
 	{
 		cfg.set_configvalue("article-sort-order", "flags");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::FLAGS);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::FLAGS);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "flags-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::FLAGS);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::FLAGS);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "flags-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::FLAGS);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::FLAGS);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 
 	SECTION("author")
 	{
 		cfg.set_configvalue("article-sort-order", "author");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::AUTHOR);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::AUTHOR);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "author-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::AUTHOR);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::AUTHOR);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "author-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::AUTHOR);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::AUTHOR);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 
 	SECTION("link")
 	{
 		cfg.set_configvalue("article-sort-order", "link");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::LINK);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::LINK);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "link-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::LINK);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::LINK);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "link-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::LINK);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::LINK);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 
 	SECTION("guid")
 	{
 		cfg.set_configvalue("article-sort-order", "guid");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::GUID);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::GUID);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "guid-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::GUID);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::GUID);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "guid-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::GUID);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::GUID);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 
 	SECTION("date")
 	{
 		cfg.set_configvalue("article-sort-order", "date");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::DATE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::DATE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 
 		cfg.set_configvalue("article-sort-order", "date-asc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::DATE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::ASC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::DATE);
+		REQUIRE(sort_strategy.sd == SortDirection::ASC);
 
 		cfg.set_configvalue("article-sort-order", "date-desc");
 		sort_strategy = cfg.get_article_sort_strategy();
-		REQUIRE(sort_strategy.sm == art_sort_method_t::DATE);
-		REQUIRE(sort_strategy.sd == sort_direction_t::DESC);
+		REQUIRE(sort_strategy.sm == ArtSortMethod::DATE);
+		REQUIRE(sort_strategy.sd == SortDirection::DESC);
 	}
 }
