@@ -12,11 +12,11 @@ using namespace newsboat;
 
 namespace {
 
-std::vector<std::shared_ptr<rss_feed>> get_five_empty_feeds(cache* rsscache)
+std::vector<std::shared_ptr<RssFeed>> get_five_empty_feeds(Cache* rsscache)
 {
-	std::vector<std::shared_ptr<rss_feed>> feeds;
+	std::vector<std::shared_ptr<RssFeed>> feeds;
 	for (int i = 0; i < 5; ++i) {
-		const auto feed = std::make_shared<rss_feed>(rsscache);
+		const auto feed = std::make_shared<RssFeed>(rsscache);
 		feeds.push_back(feed);
 	}
 	return feeds;
@@ -24,11 +24,11 @@ std::vector<std::shared_ptr<rss_feed>> get_five_empty_feeds(cache* rsscache)
 
 } // anonymous namespace
 
-TEST_CASE("get_feed() returns feed by its position number", "[feedcontainer]")
+TEST_CASE("get_feed() returns feed by its position number", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	int i = 0;
 	for (const auto& feed : feeds) {
@@ -46,11 +46,11 @@ TEST_CASE("get_feed() returns feed by its position number", "[feedcontainer]")
 }
 
 TEST_CASE("get_all_feeds() returns copy of FeedContainer's feed vector",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	feedcontainer.set_feeds(feeds);
 
@@ -58,13 +58,13 @@ TEST_CASE("get_all_feeds() returns copy of FeedContainer's feed vector",
 }
 
 TEST_CASE("add_feed() adds specific feed to its \"feeds\" vector",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	feedcontainer.set_feeds({});
-	const auto feed = std::make_shared<rss_feed>(&rsscache);
+	const auto feed = std::make_shared<RssFeed>(&rsscache);
 	feed->set_title("Example feed");
 
 	feedcontainer.add_feed(feed);
@@ -72,19 +72,19 @@ TEST_CASE("add_feed() adds specific feed to its \"feeds\" vector",
 	REQUIRE(feedcontainer.get_feed(0)->title_raw() == "Example feed");
 }
 
-TEST_CASE("populate_query_feeds() populates query feeds", "[feedcontainer]")
+TEST_CASE("populate_query_feeds() populates query feeds", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	auto feeds = get_five_empty_feeds(&rsscache);
 	for (int j = 0; j < 5; ++j) {
-		const auto item = std::make_shared<rss_item>(&rsscache);
+		const auto item = std::make_shared<RssItem>(&rsscache);
 		item->set_unread_nowrite(true);
 		feeds[j]->add_item(item);
 	}
 
-	const auto feed = std::make_shared<rss_feed>(&rsscache);
+	const auto feed = std::make_shared<RssFeed>(&rsscache);
 	feed->set_rssurl("query:a title:unread = \"yes\"");
 	feeds.push_back(feed);
 
@@ -95,11 +95,11 @@ TEST_CASE("populate_query_feeds() populates query feeds", "[feedcontainer]")
 }
 
 TEST_CASE("set_feeds() sets FeedContainer's feed vector to the given one",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 
 	feedcontainer.set_feeds(feeds);
@@ -107,11 +107,11 @@ TEST_CASE("set_feeds() sets FeedContainer's feed vector to the given one",
 	REQUIRE(feedcontainer.feeds == feeds);
 }
 
-TEST_CASE("get_feed_by_url() returns feed by its URL", "[feedcontainer]")
+TEST_CASE("get_feed_by_url() returns feed by its URL", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	int i = 0;
 	for (const auto& feed : feeds) {
@@ -131,11 +131,11 @@ TEST_CASE("get_feed_by_url() returns feed by its URL", "[feedcontainer]")
 TEST_CASE(
 	"get_feed_by_url() returns nullptr when it cannot find feed with "
 	"given URL",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	int i = 0;
 	for (const auto& feed : feeds) {
@@ -148,11 +148,11 @@ TEST_CASE(
 	REQUIRE(feed == nullptr);
 }
 
-TEST_CASE("Throws on get_feed() with pos out of range", "[feedcontainer]")
+TEST_CASE("Throws on get_feed() with pos out of range", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	feedcontainer.set_feeds(get_five_empty_feeds(&rsscache));
 
 	REQUIRE_NOTHROW(feedcontainer.get_feed(4));
@@ -161,11 +161,11 @@ TEST_CASE("Throws on get_feed() with pos out of range", "[feedcontainer]")
 }
 
 TEST_CASE("Returns correct number using get_feed_count_by_tag()",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	feedcontainer.set_feeds(get_five_empty_feeds(&rsscache));
 	feedcontainer.get_feed(0)->set_tags({"Chicken", "Horse"});
 	feedcontainer.get_feed(1)->set_tags({"Horse", "Duck"});
@@ -178,15 +178,15 @@ TEST_CASE("Returns correct number using get_feed_count_by_tag()",
 	REQUIRE(feedcontainer.get_feed_count_per_tag("Duck") == 3);
 }
 
-TEST_CASE("Correctly returns pos of next unread item", "[feedcontainer]")
+TEST_CASE("Correctly returns pos of next unread item", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	int i = 0;
 	for (const auto& feed : feeds) {
-		const auto item = std::make_shared<rss_item>(&rsscache);
+		const auto item = std::make_shared<RssItem>(&rsscache);
 		if ((i % 2) == 0)
 			item->set_unread_nowrite(true);
 		else
@@ -201,22 +201,22 @@ TEST_CASE("Correctly returns pos of next unread item", "[feedcontainer]")
 }
 
 TEST_CASE("feeds_size() returns FeedContainer's current feed vector size",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	feedcontainer.set_feeds(feeds);
 
 	REQUIRE(feedcontainer.feeds_size() == feeds.size());
 }
 
-TEST_CASE("Correctly sorts feeds", "[feedcontainer]")
+TEST_CASE("Correctly sorts feeds", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	feedcontainer.set_feeds(feeds);
 
@@ -310,13 +310,13 @@ TEST_CASE("Correctly sorts feeds", "[feedcontainer]")
 		REQUIRE(sorted_feeds[4]->title() == "taggy");
 	}
 
-	feeds[0]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[0]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[1]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[1]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[1]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[2]->add_item(std::make_shared<rss_item>(&rsscache));
-	feeds[3]->add_item(std::make_shared<rss_item>(&rsscache));
+	feeds[0]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[0]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[1]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[1]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[1]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[2]->add_item(std::make_shared<RssItem>(&rsscache));
+	feeds[3]->add_item(std::make_shared<RssItem>(&rsscache));
 
 	SECTION("by articlecount asc")
 	{
@@ -342,12 +342,12 @@ TEST_CASE("Correctly sorts feeds", "[feedcontainer]")
 		REQUIRE(sorted_feeds[4]->total_item_count() == 3);
 	}
 
-	auto item = std::make_shared<rss_item>(&rsscache);
+	auto item = std::make_shared<RssItem>(&rsscache);
 	item->set_unread_nowrite(false);
 	feeds[1]->add_item(item);
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	feeds[2]->add_item(item);
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	item->set_unread_nowrite(false);
 	feeds[4]->add_item(item);
 
@@ -377,19 +377,19 @@ TEST_CASE("Correctly sorts feeds", "[feedcontainer]")
 		REQUIRE(sorted_feeds[4]->unread_item_count() == 3);
 	}
 
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	item->set_pubDate(93);
 	feeds[0]->add_item(item);
 
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	item->set_pubDate(42);
 	feeds[1]->add_item(item);
 
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	item->set_pubDate(69);
 	feeds[2]->add_item(item);
 
-	item = std::make_shared<rss_item>(&rsscache);
+	item = std::make_shared<RssItem>(&rsscache);
 	item->set_pubDate(23);
 	feeds[3]->add_item(item);
 
@@ -419,15 +419,15 @@ TEST_CASE("Correctly sorts feeds", "[feedcontainer]")
 }
 
 TEST_CASE("mark_all_feed_items_read() marks all of feed's items as read",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	const auto feed = feeds.at(0);
 	for (int j = 0; j < 5; ++j) {
-		const auto item = std::make_shared<rss_item>(&rsscache);
+		const auto item = std::make_shared<RssItem>(&rsscache);
 		item->set_unread_nowrite(true);
 		feed->add_item(item);
 	}
@@ -441,16 +441,16 @@ TEST_CASE("mark_all_feed_items_read() marks all of feed's items as read",
 }
 
 TEST_CASE("mark_all_feeds_read() marks all items in all feeds as read",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 
 	for (const auto& feed : feeds) {
 		for (int j = 0; j < 3; ++j) {
-			const auto item = std::make_shared<rss_item>(&rsscache);
+			const auto item = std::make_shared<RssItem>(&rsscache);
 			item->set_unread_nowrite(true);
 			feed->add_item(item);
 		}
@@ -469,16 +469,16 @@ TEST_CASE("mark_all_feeds_read() marks all items in all feeds as read",
 TEST_CASE(
 	"reset_feeds_status() changes status of all feeds to \"to be "
 	"downloaded\"",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
-	feeds[0]->set_status(dl_status::SUCCESS);
-	feeds[1]->set_status(dl_status::TO_BE_DOWNLOADED);
-	feeds[2]->set_status(dl_status::DURING_DOWNLOAD);
-	feeds[3]->set_status(dl_status::DL_ERROR);
+	feeds[0]->set_status(DlStatus::SUCCESS);
+	feeds[1]->set_status(DlStatus::TO_BE_DOWNLOADED);
+	feeds[2]->set_status(DlStatus::DURING_DOWNLOAD);
+	feeds[3]->set_status(DlStatus::DL_ERROR);
 	feedcontainer.set_feeds(feeds);
 
 	feedcontainer.reset_feeds_status();
@@ -488,15 +488,15 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("clear_feeds_items() clears all of feed's items", "[feedcontainer]")
+TEST_CASE("clear_feeds_items() clears all of feed's items", "[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	feedcontainer.set_feeds({});
-	const auto feed = std::make_shared<rss_feed>(&rsscache);
+	const auto feed = std::make_shared<RssFeed>(&rsscache);
 	for (int j = 0; j < 5; ++j) {
-		feed->add_item(std::make_shared<rss_item>(&rsscache));
+		feed->add_item(std::make_shared<RssItem>(&rsscache));
 	}
 	feedcontainer.add_feed(feed);
 
@@ -508,16 +508,16 @@ TEST_CASE("clear_feeds_items() clears all of feed's items", "[feedcontainer]")
 TEST_CASE(
 	"unread_feed_count() returns number of feeds that have unread items in "
 	"them",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	for (int j = 0; j < 5; ++j) {
 		// Make sure that number of unread items in feed doesn't matter
-		const auto item = std::make_shared<rss_item>(&rsscache);
-		const auto item2 = std::make_shared<rss_item>(&rsscache);
+		const auto item = std::make_shared<RssItem>(&rsscache);
+		const auto item2 = std::make_shared<RssItem>(&rsscache);
 		if ((j % 2) == 0) {
 			item->set_unread_nowrite(false);
 			item2->set_unread_nowrite(false);
@@ -531,15 +531,15 @@ TEST_CASE(
 }
 
 TEST_CASE("unread_item_count() returns number of unread items in all feeds",
-	"[feedcontainer]")
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
-	configcontainer cfg;
-	cache rsscache(":memory:", &cfg);
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
 	const auto feeds = get_five_empty_feeds(&rsscache);
 	for (int j = 0; j < 5; ++j) {
-		const auto item = std::make_shared<rss_item>(&rsscache);
-		const auto item2 = std::make_shared<rss_item>(&rsscache);
+		const auto item = std::make_shared<RssItem>(&rsscache);
+		const auto item2 = std::make_shared<RssItem>(&rsscache);
 		if ((j % 2) == 0) {
 			item->set_unread_nowrite(false);
 			item2->set_unread_nowrite(false);
