@@ -77,11 +77,11 @@ struct StringMaker<std::pair<newsboat::LineType, std::string>> {
 TEST_CASE(
 	"Links are rendered as underlined text with reference number in "
 	"square brackets",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer rnd;
+	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	rnd.render("<a href=\"http://slashdot.org/\">slashdot</a>",
 		lines,
@@ -97,14 +97,14 @@ TEST_CASE(
 		p(LineType::softwrappable, "[1]: http://slashdot.org/ (link)"));
 
 	REQUIRE(links[0].first == "http://slashdot.org/");
-	REQUIRE(links[0].second == link_type::HREF);
+	REQUIRE(links[0].second == LinkType::HREF);
 }
 
-TEST_CASE("<br>, <br/> and <br /> result in a line break", "[htmlrenderer]")
+TEST_CASE("<br>, <br/> and <br /> result in a line break", "[HtmlRenderer]")
 {
-	htmlrenderer rnd;
+	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	for (std::string tag : {"<br>", "<br/>", "<br />"}) {
 		SECTION(tag)
@@ -118,33 +118,33 @@ TEST_CASE("<br>, <br/> and <br /> result in a line break", "[htmlrenderer]")
 	}
 }
 
-TEST_CASE("Superscript is rendered with caret symbol", "[htmlrenderer]")
+TEST_CASE("Superscript is rendered with caret symbol", "[HtmlRenderer]")
 {
-	htmlrenderer rnd;
+	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	rnd.render("3<sup>10</sup>", lines, links, "");
 	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "3^10"));
 }
 
-TEST_CASE("Subscript is rendered with square brackets", "[htmlrenderer]")
+TEST_CASE("Subscript is rendered with square brackets", "[HtmlRenderer]")
 {
-	htmlrenderer rnd;
+	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	rnd.render("A<sub>i</sub>", lines, links, "");
 	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "A[i]"));
 }
 
-TEST_CASE("Script tags are ignored", "[htmlrenderer]")
+TEST_CASE("Script tags are ignored", "[HtmlRenderer]")
 {
-	htmlrenderer rnd;
+	HtmlRenderer rnd;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	rnd.render("abc<script></script>", lines, links, "");
 	REQUIRE(lines.size() == 1);
@@ -152,9 +152,9 @@ TEST_CASE("Script tags are ignored", "[htmlrenderer]")
 }
 
 TEST_CASE("format_ol_count formats list count in specified format",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	SECTION("format to digit")
 	{
@@ -201,48 +201,48 @@ TEST_CASE("format_ol_count formats list count in specified format",
 }
 
 TEST_CASE("links with same URL are coalesced under one number",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<a href='http://example.com/about'>About us</a>"
 		"<a href='http://example.com/about'>Another link</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(links.size() == 1);
 	REQUIRE(links[0].first == "http://example.com/about");
-	REQUIRE(links[0].second == link_type::HREF);
+	REQUIRE(links[0].second == LinkType::HREF);
 }
 
-TEST_CASE("links with different URLs have different numbers", "[htmlrenderer]")
+TEST_CASE("links with different URLs have different numbers", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<a href='http://example.com/one'>One</a>"
 		"<a href='http://example.com/two'>Two</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(links.size() == 2);
 	REQUIRE(links[0].first == "http://example.com/one");
-	REQUIRE(links[0].second == link_type::HREF);
+	REQUIRE(links[0].second == LinkType::HREF);
 	REQUIRE(links[1].first == "http://example.com/two");
-	REQUIRE(links[1].second == link_type::HREF);
+	REQUIRE(links[1].second == LinkType::HREF);
 }
 
 TEST_CASE("link without `href' is neither highlighted nor added to links list",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<a>test</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -252,13 +252,13 @@ TEST_CASE("link without `href' is neither highlighted nor added to links list",
 
 TEST_CASE(
 	"link with empty `href' is neither highlighted nor added to links list",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<a href=''>test</a>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -266,55 +266,55 @@ TEST_CASE(
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<strong> is rendered in bold font", "[htmlrenderer]")
+TEST_CASE("<strong> is rendered in bold font", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<strong>test</strong>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "<b>test</>"));
 }
 
-TEST_CASE("<u> is rendered as underlined text", "[htmlrenderer]")
+TEST_CASE("<u> is rendered as underlined text", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<u>test</u>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "<u>test</>"));
 }
 
-TEST_CASE("<q> is rendered as text in quotes", "[htmlrenderer]")
+TEST_CASE("<q> is rendered as text in quotes", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<q>test</q>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
 	REQUIRE(lines[0] == p(LineType::wrappable, "\"test\""));
 }
 
-TEST_CASE("Flash <embed>s are added to links if `src' is set", "[htmlrenderer]")
+TEST_CASE("Flash <embed>s are added to links if `src' is set", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<embed type='application/x-shockwave-flash'"
 		"src='http://example.com/game.swf'>"
 		"</embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
@@ -326,62 +326,62 @@ TEST_CASE("Flash <embed>s are added to links if `src' is set", "[htmlrenderer]")
 			"[1]: http://example.com/game.swf (embedded flash)"));
 	REQUIRE(links.size() == 1);
 	REQUIRE(links[0].first == "http://example.com/game.swf");
-	REQUIRE(links[0].second == link_type::EMBED);
+	REQUIRE(links[0].second == LinkType::EMBED);
 }
 
-TEST_CASE("Flash <embed>s are ignored if `src' is not set", "[htmlrenderer]")
+TEST_CASE("Flash <embed>s are ignored if `src' is not set", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<embed type='application/x-shockwave-flash'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("non-flash <embed>s are ignored", "[htmlrenderer]")
+TEST_CASE("non-flash <embed>s are ignored", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<embed type='whatever'"
 		"src='http://example.com/thingy'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<embed>s are ignored if `type' is not set", "[htmlrenderer]")
+TEST_CASE("<embed>s are ignored if `type' is not set", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<embed src='http://example.com/yet.another.thingy'></embed>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("spaces and line breaks are preserved inside <pre>", "[htmlrenderer]")
+TEST_CASE("spaces and line breaks are preserved inside <pre>", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<pre>oh cool\n"
 		"  check this\tstuff  out!\n"
 		"</pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 2);
@@ -391,9 +391,9 @@ TEST_CASE("spaces and line breaks are preserved inside <pre>", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("tags still work inside <pre>", "[htmlrenderer]")
+TEST_CASE("tags still work inside <pre>", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<pre>"
@@ -401,7 +401,7 @@ TEST_CASE("tags still work inside <pre>", "[htmlrenderer]")
 		"<u>underlined text</u>"
 		"</pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -411,14 +411,14 @@ TEST_CASE("tags still work inside <pre>", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<img> results in a placeholder and a link", "[htmlrenderer]")
+TEST_CASE("<img> results in a placeholder and a link", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<img src='http://example.com/image.png'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
@@ -430,16 +430,16 @@ TEST_CASE("<img> results in a placeholder and a link", "[htmlrenderer]")
 			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
 	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == link_type::IMG);
+	REQUIRE(links[0].second == LinkType::IMG);
 }
 
-TEST_CASE("<img>s without `src' are ignored", "[htmlrenderer]")
+TEST_CASE("<img>s without `src' are ignored", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input = "<img></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 0);
@@ -447,15 +447,15 @@ TEST_CASE("<img>s without `src' are ignored", "[htmlrenderer]")
 }
 
 TEST_CASE("title is mentioned in placeholder if <img> has `title'",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<img src='http://example.com/image.png'"
 		"title='Just a test image'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
@@ -468,22 +468,22 @@ TEST_CASE("title is mentioned in placeholder if <img> has `title'",
 			"[1]: http://example.com/image.png (image)"));
 	REQUIRE(links.size() == 1);
 	REQUIRE(links[0].first == "http://example.com/image.png");
-	REQUIRE(links[0].second == link_type::IMG);
+	REQUIRE(links[0].second == LinkType::IMG);
 }
 
 TEST_CASE(
 	"URL of <img> with data inside `src' is replaced with string "
 	"\"inline image\"",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<img src='data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUA"
 		"AAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO"
 		"9TXL0Y4OHwAAAABJRU5ErkJggg==' alt='Red dot' />";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
@@ -494,13 +494,13 @@ TEST_CASE(
 		p(LineType::softwrappable, "[1]: inline image (image)"));
 	REQUIRE(links.size() == 1);
 	REQUIRE(links[0].first == "inline image");
-	REQUIRE(links[0].second == link_type::IMG);
+	REQUIRE(links[0].second == LinkType::IMG);
 }
 
 TEST_CASE("<blockquote> is indented and is separated by empty lines",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<blockquote>"
@@ -509,7 +509,7 @@ TEST_CASE("<blockquote> is indented and is separated by empty lines",
 		"&mdash;Randy Pausch"
 		"</blockquote>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 3);
@@ -525,9 +525,9 @@ TEST_CASE("<blockquote> is indented and is separated by empty lines",
 TEST_CASE(
 	"<dl>, <dt> and <dd> are rendered as a set of paragraphs with term "
 	"descriptions indented to the right",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		// Opinions are lifted from the "Monstrous Regiment" by Terry
@@ -539,7 +539,7 @@ TEST_CASE(
 		"<dd>Soldier's friend</dd>"
 		"</dl>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 8);
@@ -554,11 +554,11 @@ TEST_CASE(
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<h[2-6]> and <p>", "[htmlrenderer]")
+TEST_CASE("<h[2-6]> and <p>", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	SECTION("<h1> is rendered with setext-style underlining")
 	{
@@ -645,9 +645,9 @@ TEST_CASE("<h[2-6]> and <p>", "[htmlrenderer]")
 }
 
 TEST_CASE("whitespace is erased at the beginning of the paragraph",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<p>"
@@ -655,7 +655,7 @@ TEST_CASE("whitespace is erased at the beginning of the paragraph",
 		"here comes the text"
 		"</p>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -663,14 +663,14 @@ TEST_CASE("whitespace is erased at the beginning of the paragraph",
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("newlines are replaced with space", "[htmlrenderer]")
+TEST_CASE("newlines are replaced with space", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"newlines\nshould\nbe\nreplaced\nwith\na\nspace\ncharacter.";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -680,9 +680,9 @@ TEST_CASE("newlines are replaced with space", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("paragraph is just a long line of text", "[htmlrenderer]")
+TEST_CASE("paragraph is just a long line of text", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 
 	const std::string input =
 		"<p>"
@@ -690,7 +690,7 @@ TEST_CASE("paragraph is just a long line of text", "[htmlrenderer]")
 		"width"
 		"</p>";
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 1);
@@ -701,11 +701,11 @@ TEST_CASE("paragraph is just a long line of text", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("default style for <ol> is Arabic numerals", "[htmlrenderer]")
+TEST_CASE("default style for <ol> is Arabic numerals", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	SECTION("no `type' attribute")
 	{
@@ -738,11 +738,11 @@ TEST_CASE("default style for <ol> is Arabic numerals", "[htmlrenderer]")
 	}
 }
 
-TEST_CASE("default starting number for <ol> is 1", "[htmlrenderer]")
+TEST_CASE("default starting number for <ol> is 1", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	SECTION("no `start' attribute")
 	{
@@ -775,11 +775,11 @@ TEST_CASE("default starting number for <ol> is 1", "[htmlrenderer]")
 	}
 }
 
-TEST_CASE("type='1' for <ol> means Arabic numbering", "[htmlrenderer]")
+TEST_CASE("type='1' for <ol> means Arabic numbering", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='1'>"
 		"<li>one</li>"
@@ -794,11 +794,11 @@ TEST_CASE("type='1' for <ol> means Arabic numbering", "[htmlrenderer]")
 }
 
 TEST_CASE("type='a' for <ol> means lowercase alphabetic numbering",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='a'>"
 		"<li>one</li>"
@@ -813,11 +813,11 @@ TEST_CASE("type='a' for <ol> means lowercase alphabetic numbering",
 }
 
 TEST_CASE("type='A' for <ol> means uppercase alphabetic numbering",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='A'>"
 		"<li>one</li>"
@@ -831,11 +831,11 @@ TEST_CASE("type='A' for <ol> means uppercase alphabetic numbering",
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("type='i' for <ol> means lowercase Roman numbering", "[htmlrenderer]")
+TEST_CASE("type='i' for <ol> means lowercase Roman numbering", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='i'>"
 		"<li>one</li>"
@@ -849,11 +849,11 @@ TEST_CASE("type='i' for <ol> means lowercase Roman numbering", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("type='I' for <ol> means uppercase Roman numbering", "[htmlrenderer]")
+TEST_CASE("type='I' for <ol> means uppercase Roman numbering", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='I'>"
 		"<li>one</li>"
@@ -868,11 +868,11 @@ TEST_CASE("type='I' for <ol> means uppercase Roman numbering", "[htmlrenderer]")
 }
 
 TEST_CASE("every next <li> implicitly closes the previous one",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<ol type='I'>"
 		"<li>one"
@@ -891,11 +891,11 @@ TEST_CASE("every next <li> implicitly closes the previous one",
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<style> tags are ignored", "[htmlrenderer]")
+TEST_CASE("<style> tags are ignored", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 	const std::string input =
 		"<style><h1>ignore me</h1><p>and me</p> body{width: "
 		"100%;}</style>";
@@ -905,11 +905,11 @@ TEST_CASE("<style> tags are ignored", "[htmlrenderer]")
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("<hr> is not a string, but a special type of line", "[htmlrenderer]")
+TEST_CASE("<hr> is not a string, but a special type of line", "[HtmlRenderer]")
 {
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
-	htmlrenderer r;
+	std::vector<LinkPair> links;
+	HtmlRenderer r;
 	const std::string input = "<hr>";
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
@@ -919,11 +919,11 @@ TEST_CASE("<hr> is not a string, but a special type of line", "[htmlrenderer]")
 	REQUIRE(lines[0].first == LineType::hr);
 }
 
-TEST_CASE("header rows of tables are in bold", "[htmlrenderer]")
+TEST_CASE("header rows of tables are in bold", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	SECTION("one column")
 	{
@@ -960,11 +960,11 @@ TEST_CASE("header rows of tables are in bold", "[htmlrenderer]")
 }
 
 TEST_CASE("cells are separated by space if `border' is not set",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table>"
@@ -983,11 +983,11 @@ TEST_CASE("cells are separated by space if `border' is not set",
 TEST_CASE(
 	"cells are separated by vertical bar if `border' is set (regardless "
 	"of actual value)",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	for (auto border_width = 1; border_width < 10; ++border_width) {
 		SECTION(strprintf::fmt("`border' = %u", border_width))
@@ -1011,11 +1011,11 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("tables with `border' have borders", "[htmlrenderer]")
+TEST_CASE("tables with `border' have borders", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1034,11 +1034,11 @@ TEST_CASE("tables with `border' have borders", "[htmlrenderer]")
 }
 
 TEST_CASE("if document ends before </table> is found, table is rendered anyway",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1055,11 +1055,11 @@ TEST_CASE("if document ends before </table> is found, table is rendered anyway",
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("tables can be nested", "[htmlrenderer]")
+TEST_CASE("tables can be nested", "[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1103,11 +1103,11 @@ TEST_CASE("tables can be nested", "[htmlrenderer]")
 TEST_CASE(
 	"if <td> appears inside table but outside of a row, one is created "
 	"implicitly",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1125,11 +1125,11 @@ TEST_CASE(
 }
 
 TEST_CASE("previous row is implicitly closed when <tr> is found",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1150,11 +1150,11 @@ TEST_CASE("previous row is implicitly closed when <tr> is found",
 TEST_CASE(
 	"free-standing text outside of <td> is implicitly concatenated with "
 	"the next cell",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<table border='1'>"
@@ -1172,11 +1172,11 @@ TEST_CASE(
 }
 
 TEST_CASE("text within <ituneshack> is to be treated specially",
-	"[htmlrenderer]")
+	"[HtmlRenderer]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"<ituneshack>"
@@ -1195,12 +1195,12 @@ TEST_CASE("text within <ituneshack> is to be treated specially",
 	REQUIRE(links.size() == 0);
 }
 
-TEST_CASE("When rendeing text, htmlrenderer strips leading whitespace",
-	"[htmlrenderer][issue204]")
+TEST_CASE("When rendeing text, HtmlRenderer strips leading whitespace",
+	"[HtmlRenderer][issue204]")
 {
-	htmlrenderer r;
+	HtmlRenderer r;
 	std::vector<std::pair<LineType, std::string>> lines;
-	std::vector<linkpair> links;
+	std::vector<LinkPair> links;
 
 	const std::string input =
 		"		<br />\n"
