@@ -6,9 +6,9 @@
 
 using namespace newsboat;
 
-TEST_CASE("get_operation()", "[keymap]")
+TEST_CASE("get_operation()", "[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_operation("u", "article") == OP_SHOWURLS);
 	REQUIRE(k.get_operation("X", "feedlist") == OP_NIL);
@@ -22,9 +22,9 @@ TEST_CASE("get_operation()", "[keymap]")
 	}
 }
 
-TEST_CASE("unset_key() and set_key()", "[keymap]")
+TEST_CASE("unset_key() and set_key()", "[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_operation("ENTER", "feedlist") == OP_OPEN);
 	REQUIRE(k.getkey(OP_OPEN, "all") == "ENTER");
@@ -43,23 +43,68 @@ TEST_CASE("unset_key() and set_key()", "[keymap]")
 	}
 }
 
-TEST_CASE("get_opcode()", "[keymap]")
+TEST_CASE(
+	"unset_all_keys() clears the keymap from key bindings for a given context",
+	"[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	SECTION("KeyMap has most of the keys set up by default") {
+		KeyMap k(KM_NEWSBOAT);
+
+		for (int i = OP_QUIT; i < OP_NB_MAX; ++i) {
+			if (i == OP_OPENALLUNREADINBROWSER ||
+					i == OP_MARKALLABOVEASREAD ||
+					i == OP_OPENALLUNREADINBROWSER_AND_MARK) {
+				continue;
+			}
+			REQUIRE(k.getkey(static_cast<Operation>(i), "all") != "<none>");
+		}
+	}
+
+	SECTION("\"all\" context clears the keymap from all key bindings") {
+		KeyMap k(KM_NEWSBOAT);
+		k.unset_all_keys("all");
+
+		for (int i = OP_NB_MIN; i < OP_NB_MAX; ++i) {
+			REQUIRE(k.getkey(static_cast<Operation>(i), "all") == "<none>");
+		}
+	}
+
+	SECTION("Clears key bindings just for a given context") {
+		KeyMap k(KM_NEWSBOAT);
+		k.unset_all_keys("articlelist");
+
+		for (int i = OP_NB_MIN; i < OP_NB_MAX; ++i) {
+			REQUIRE(k.getkey(static_cast<Operation>(i), "articlelist") == "<none>");
+		}
+
+		for (int i = OP_QUIT; i < OP_NB_MAX; ++i) {
+			if (i == OP_OPENALLUNREADINBROWSER ||
+					i == OP_MARKALLABOVEASREAD ||
+					i == OP_OPENALLUNREADINBROWSER_AND_MARK) {
+				continue;
+			}
+			REQUIRE(k.getkey(static_cast<Operation>(i), "feedlist") != "<none>");
+		}
+	}
+}
+
+TEST_CASE("get_opcode()", "[KeyMap]")
+{
+	KeyMap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_opcode("open") == OP_OPEN);
 	REQUIRE(k.get_opcode("some-noexistent-operation") == OP_NIL);
 }
 
-TEST_CASE("getkey()", "[keymap]")
+TEST_CASE("getkey()", "[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 
 	SECTION("Retrieves general bindings")
 	{
 		REQUIRE(k.getkey(OP_OPEN, "all") == "ENTER");
 		REQUIRE(k.getkey(OP_TOGGLEITEMREAD, "all") == "N");
-		REQUIRE(k.getkey(static_cast<operation>(30000), "all") ==
+		REQUIRE(k.getkey(static_cast<Operation>(30000), "all") ==
 			"<none>");
 	}
 
@@ -70,11 +115,19 @@ TEST_CASE("getkey()", "[keymap]")
 		REQUIRE(k.getkey(OP_QUIT, "article") == "O");
 		REQUIRE(k.getkey(OP_QUIT, "all") == "q");
 	}
+
+	SECTION("Returns context-specific binding if asked to search in all contexts")
+	{
+		k.unset_all_keys("all");
+		REQUIRE(k.getkey(OP_QUIT, "all") == "<none>");
+		k.set_key(OP_QUIT, "O", "article");
+		REQUIRE(k.getkey(OP_QUIT, "all") == "O");
+	}
 }
 
-TEST_CASE("get_key()", "[keymap]")
+TEST_CASE("get_key()", "[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_key(" ") == ' ');
 	REQUIRE(k.get_key("U") == 'U');
@@ -85,19 +138,19 @@ TEST_CASE("get_key()", "[keymap]")
 	REQUIRE(k.get_key("^A") == '\001');
 }
 
-TEST_CASE("handle_action()", "[keymap]")
+TEST_CASE("handle_action()", "[KeyMap]")
 {
-	keymap k(KM_NEWSBOAT);
+	KeyMap k(KM_NEWSBOAT);
 	std::vector<std::string> params;
 
 	SECTION("without parameters")
 	{
 		REQUIRE_THROWS_AS(k.handle_action("bind-key", params),
-			confighandlerexception);
+			ConfigHandlerException);
 		REQUIRE_THROWS_AS(k.handle_action("unbind-key", params),
-			confighandlerexception);
+			ConfigHandlerException);
 		REQUIRE_THROWS_AS(k.handle_action("macro", params),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 
 	SECTION("with one parameter")
@@ -105,7 +158,7 @@ TEST_CASE("handle_action()", "[keymap]")
 		params.push_back("r");
 
 		REQUIRE_THROWS_AS(k.handle_action("bind-key", params),
-			confighandlerexception);
+			ConfigHandlerException);
 		REQUIRE_NOTHROW(k.handle_action("unbind-key", params));
 	}
 
@@ -115,7 +168,7 @@ TEST_CASE("handle_action()", "[keymap]")
 		params.push_back("open");
 		REQUIRE_NOTHROW(k.handle_action("bind-key", params));
 		REQUIRE_THROWS_AS(k.handle_action("an-invalid-action", params),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 
 	SECTION("invalid-op throws exception")
@@ -124,8 +177,8 @@ TEST_CASE("handle_action()", "[keymap]")
 		params.push_back("invalid-op");
 
 		REQUIRE_THROWS_AS(k.handle_action("bind-key", params),
-			confighandlerexception);
+			ConfigHandlerException);
 		REQUIRE_THROWS_AS(k.handle_action("macro", params),
-			confighandlerexception);
+			ConfigHandlerException);
 	}
 }
