@@ -5,9 +5,9 @@
 using namespace newsboat;
 
 TEST_CASE("add_line(), add_lines(), get_lines_count() and clear()",
-	"[listformatter]")
+	"[ListFormatter]")
 {
-	listformatter fmt;
+	ListFormatter fmt;
 
 	REQUIRE(fmt.get_lines_count() == 0);
 
@@ -34,22 +34,22 @@ TEST_CASE("add_line(), add_lines(), get_lines_count() and clear()",
 }
 
 TEST_CASE("add_line() splits overly long sequences to fit width",
-	"[listformatter]")
+	"[ListFormatter]")
 {
-	listformatter fmt;
+	ListFormatter fmt;
 
 	SECTION("ordinary text")
 	{
 		fmt.add_line("123456789_", UINT_MAX, 10);
 		fmt.add_line("_987654321", UINT_MAX, 10);
-		fmt.add_line("listformatter doesn't care about word boundaries",
+		fmt.add_line("ListFormatter doesn't care about word boundaries",
 			UINT_MAX,
 			10);
 		std::string expected =
 			"{list"
 			"{listitem text:\"123456789_\"}"
 			"{listitem text:\"_987654321\"}"
-			"{listitem text:\"listformat\"}"
+			"{listitem text:\"ListFormat\"}"
 			"{listitem text:\"ter doesn'\"}"
 			"{listitem text:\"t care abo\"}"
 			"{listitem text:\"ut word bo\"}"
@@ -62,14 +62,14 @@ TEST_CASE("add_line() splits overly long sequences to fit width",
 	{
 		fmt.add_line("123456789_", 1, 10);
 		fmt.add_line("_987654321", 2, 10);
-		fmt.add_line("listformatter doesn't care about word boundaries",
+		fmt.add_line("ListFormatter doesn't care about word boundaries",
 			3,
 			10);
 		std::string expected =
 			"{list"
 			"{listitem[1] text:\"123456789_\"}"
 			"{listitem[2] text:\"_987654321\"}"
-			"{listitem[3] text:\"listformat\"}"
+			"{listitem[3] text:\"ListFormat\"}"
 			"{listitem[3] text:\"ter doesn'\"}"
 			"{listitem[3] text:\"t care abo\"}"
 			"{listitem[3] text:\"ut word bo\"}"
@@ -79,9 +79,9 @@ TEST_CASE("add_line() splits overly long sequences to fit width",
 	}
 }
 
-TEST_CASE("set_line() replaces the item in a list", "[listformatter]")
+TEST_CASE("set_line() replaces the item in a list", "[ListFormatter]")
 {
-	listformatter fmt;
+	ListFormatter fmt;
 
 	fmt.add_line("hello", 1, 5);
 	fmt.add_line("goodbye", 2, 5);
@@ -106,13 +106,13 @@ TEST_CASE("set_line() replaces the item in a list", "[listformatter]")
 }
 
 TEST_CASE("format_list() uses regex manager if one is passed",
-	"[listformatter]")
+	"[ListFormatter]")
 {
-	listformatter fmt;
+	ListFormatter fmt;
 
 	fmt.add_line("Highlight me please!");
 
-	regexmanager rxmgr;
+	RegexManager rxmgr;
 	// the choice of green text on red background does not reflect my
 	// personal taste (or lack thereof) :)
 	rxmgr.handle_action(
