@@ -1,8 +1,12 @@
 #include "utils.h"
 
-#include <unistd.h> // chdir()
+#include <chrono>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "3rd-party/catch.hpp"
+#include "test-helpers.h"
 
 using namespace newsboat;
 
@@ -146,6 +150,49 @@ TEST_CASE("tokenize_quoted() doesn't un-escape escaped backticks", "[utils]")
 	REQUIRE(tokens[1] == "\\`foobar `bla`\\`");
 }
 
+TEST_CASE("tokenize_nl() split a string into delimiters and fields", "[utils]")
+{
+	std::vector<std::string> tokens;
+
+	SECTION("a few words separated by newlines")
+	{
+		tokens = utils::tokenize_nl("first\nsecond\nthird");
+
+		REQUIRE(tokens.size() == 5);
+		REQUIRE(tokens[0] == "first");
+		REQUIRE(tokens[2] == "second");
+		REQUIRE(tokens[4] == "third");
+	}
+
+	SECTION("several preceding delimiters")
+	{
+		tokens = utils::tokenize_nl("\n\n\nonly");
+
+		REQUIRE(tokens.size() == 4);
+		REQUIRE(tokens[3] == "only");
+	}
+
+	SECTION("redundant internal delimiters")
+	{
+		tokens = utils::tokenize_nl("first\nsecond\n\nthird");
+
+		REQUIRE(tokens.size() == 6);
+		REQUIRE(tokens[0] == "first");
+		REQUIRE(tokens[2] == "second");
+		REQUIRE(tokens[5] == "third");
+	}
+
+	SECTION("custom delimiter")
+	{
+		tokens = utils::tokenize_nl("first\nsecond\nthird","i");
+
+		REQUIRE(tokens.size() == 5);
+		REQUIRE(tokens[0] == "f");
+		REQUIRE(tokens[2] == "rst\nsecond\nth");
+		REQUIRE(tokens[4] == "rd");
+	}
+}
+
 TEST_CASE(
 	"consolidate_whitespace replaces multiple consecutive"
 	"whitespace with a single space",
@@ -178,6 +225,17 @@ TEST_CASE("get_command_output()", "[utils]")
 			"a-program-that-is-guaranteed-to-not-exists") == "");
 }
 
+TEST_CASE("extract_filter()", "[utils]")
+{
+	std::string filter;
+	std::string url;
+
+	utils::extract_filter("filter:~/bin/script.sh:https://newsboat.org", filter, url);
+
+	REQUIRE(filter == "~/bin/script.sh");
+	REQUIRE(url == "https://newsboat.org");
+}
+
 TEST_CASE("run_program()", "[utils]")
 {
 	char* argv[4];
@@ -198,6 +256,68 @@ TEST_CASE("run_program()", "[utils]")
 	REQUIRE(utils::run_program(argv, "") == "hello world");
 }
 
+TEST_CASE("run_command() executes the given command with a given argument",
+		"[utils]")
+{
+	TestHelpers::TempFile sentry;
+	const auto argument = sentry.getPath();
+
+	{
+		INFO("File shouldn't exist, because TempFile doesn't create it");
+
+		struct stat sb;
+		const int result = ::stat(argument.c_str(), &sb);
+		const int saved_errno = errno;
+
+		REQUIRE(result == -1);
+		REQUIRE(saved_errno == ENOENT);
+	}
+
+	utils::run_command("touch", argument);
+
+	// Sleep for 10 milliseconds, waiting for `touch` to create the file
+	::usleep(10 * 1000);
+
+	{
+		INFO("File should have been created by the `touch`");
+
+		struct stat sb;
+		const int result = ::stat(argument.c_str(), &sb);
+		REQUIRE(result == 0);
+	}
+}
+
+TEST_CASE("run_command() doesn't wait for the command to finish",
+		"[utils]")
+{
+	using namespace std::chrono;
+
+	const auto start = high_resolution_clock::now();
+
+	const std::string argument("5");
+	utils::run_command("sleep", argument);
+
+	const auto finish = high_resolution_clock::now();
+	const auto runtime = duration_cast<milliseconds>(finish - start);
+
+	// run_command finished under a second, meaning it didn't wait for
+	// a five-second sleep to finish
+	REQUIRE(runtime.count() < 1000);
+}
+
+TEST_CASE("resolve_tilde() replaces ~ with the path to the $HOME directory", "[utils]")
+{
+	SECTION("prefix-tilde replaced")
+	{
+		TestHelpers::EnvVar envVar("HOME");
+		envVar.set("test");
+		REQUIRE(utils::resolve_tilde("~") == "test");
+		REQUIRE(utils::resolve_tilde("~/") == "test/");
+		REQUIRE(utils::resolve_tilde("~/dir") == "test/dir");
+		REQUIRE(utils::resolve_tilde("/home/~") == "/home/~");
+	}
+}
+
 TEST_CASE("replace_all()", "[utils]")
 {
 	REQUIRE(utils::replace_all("aaa", "a", "b") == "bbb");
@@ -283,9 +403,9 @@ TEST_CASE("censor_url()", "[utils]")
 		"https://newsbeuter.org/");
 
 	REQUIRE(utils::censor_url("http://@newsbeuter.org/") ==
-		"http://*:*@newsbeuter.org/");
+		"http://newsbeuter.org/");
 	REQUIRE(utils::censor_url("https://@newsbeuter.org/") ==
-		"https://*:*@newsbeuter.org/");
+		"https://newsbeuter.org/");
 
 	REQUIRE(utils::censor_url("http://foo:bar@newsbeuter.org/") ==
 		"http://*:*@newsbeuter.org/");
@@ -300,11 +420,11 @@ TEST_CASE("censor_url()", "[utils]")
 	REQUIRE(utils::censor_url("xxx://aschas@newsbeuter.org/") ==
 		"xxx://*:*@newsbeuter.org/");
 
-	REQUIRE(utils::censor_url("http://foobar") == "http://foobar");
-	REQUIRE(utils::censor_url("https://foobar") == "https://foobar");
+	REQUIRE(utils::censor_url("http://foobar") == "http://foobar/");
+	REQUIRE(utils::censor_url("https://foobar") == "https://foobar/");
 
-	REQUIRE(utils::censor_url("http://aschas@host") == "http://*:*@host");
-	REQUIRE(utils::censor_url("https://aschas@host") == "https://*:*@host");
+	REQUIRE(utils::censor_url("http://aschas@host") == "http://*:*@host/");
+	REQUIRE(utils::censor_url("https://aschas@host") == "https://*:*@host/");
 
 	REQUIRE(utils::censor_url("query:name:age between 1:10") ==
 		"query:name:age between 1:10");
@@ -324,6 +444,13 @@ TEST_CASE("absolute_url()", "[utils]")
 			"bla2.html") == "http://test:test@foobar:33/bla2.html");
 }
 
+TEST_CASE("quote_for_stfl() adds a \'>\' after every \'<\'", "[utils]")
+{
+	REQUIRE(utils::quote_for_stfl("<<><><><") == "<><>><>><>><>");
+	REQUIRE(utils::quote_for_stfl("test") == "test");
+}
+
+
 TEST_CASE("quote()", "[utils]")
 {
 	REQUIRE(utils::quote("") == "\"\"");
@@ -345,6 +472,31 @@ TEST_CASE("strwidth()", "[utils]")
 	REQUIRE(utils::strwidth("xx") == 2);
 
 	REQUIRE(utils::strwidth(utils::wstr2str(L"\uF91F")) == 2);
+	REQUIRE(utils::strwidth("\07") == 1);
+}
+
+TEST_CASE("strwidth_stfl()", "[utils]")
+{
+	REQUIRE(utils::strwidth_stfl("") == 0);
+
+	REQUIRE(utils::strwidth_stfl("x<hi>x") == 3);
+
+	REQUIRE(utils::strwidth_stfl("x<>x") == 4);
+
+	REQUIRE(utils::strwidth_stfl(utils::wstr2str(L"\uF91F")) == 2);
+	REQUIRE(utils::strwidth_stfl("\07") == 1);
+}
+
+TEST_CASE("is_http_url()", "[utils]")
+{
+	REQUIRE(utils::is_http_url("http://foo.bar"));
+	REQUIRE(utils::is_http_url("https://foo.bar"));
+	REQUIRE(utils::is_http_url("http://"));
+	REQUIRE(utils::is_http_url("https://"));
+
+	REQUIRE_FALSE(utils::is_http_url("htt://foo.bar"));
+	REQUIRE_FALSE(utils::is_http_url("http:/"));
+	REQUIRE_FALSE(utils::is_http_url("foo://bar"));
 }
 
 TEST_CASE("join()", "[utils]")
@@ -511,6 +663,12 @@ TEST_CASE("utils::make_title extracts possible title from URL")
 		auto input = "https://example.com/?format=rss";
 		REQUIRE(utils::make_title(input) == "");
 	}
+
+	SECTION("Deal with an empty input")
+	{
+		auto input = "";
+		REQUIRE(utils::make_title(input) == "");
+	}
 }
 
 TEST_CASE("remove_soft_hyphens remove all U+00AD characters from a string",
@@ -762,3 +920,114 @@ TEST_CASE(
 	REQUIRE_FALSE(utils::is_special_url("exec"));
 	REQUIRE_FALSE(utils::is_special_url("   exec:"));
 }
+
+TEST_CASE(
+	"get_default_browser() returns BROWSER environment variable or "
+	"\"lynx\" if the variable is not set",
+	"[utils]")
+{
+	TestHelpers::EnvVar browserEnv("BROWSER");
+
+	// If BROWSER is not set, default browser is lynx(1)
+	browserEnv.unset();
+	REQUIRE(utils::get_default_browser() == "lynx");
+
+	browserEnv.set("firefox");
+	REQUIRE(utils::get_default_browser() == "firefox");
+
+	browserEnv.set("opera");
+	REQUIRE(utils::get_default_browser() == "opera");
+}
+
+TEST_CASE(
+	"get_basename() returns basename from a URL if available, if not"
+	" then an empty string",
+	"[utils]")
+{
+	SECTION("return basename in the presence of GET parameters")
+	{
+		REQUIRE(utils::get_basename("https://example.org/path/to/file.mp3?param=value#fragment")
+			== "file.mp3");
+		REQUIRE(utils::get_basename("https://example.org/file.mp3") == "file.mp3");
+	}
+
+	SECTION("return empty string when basename is unavailable")
+	{
+		REQUIRE(utils::get_basename("https://example.org/?param=value#fragment")
+				== "");
+		REQUIRE(utils::get_basename("https://example.org/path/to/?param=value#fragment")
+				== "");
+	}
+}
+
+TEST_CASE(
+		"get_auth_method() returns enumerated constant "
+		"on defined values and undefined values",
+		"[utils]")
+{
+	REQUIRE(utils::get_auth_method("any") == CURLAUTH_ANY);
+	REQUIRE(utils::get_auth_method("ntlm") == CURLAUTH_NTLM);
+	REQUIRE(utils::get_auth_method("basic") == CURLAUTH_BASIC);
+	REQUIRE(utils::get_auth_method("digest") == CURLAUTH_DIGEST);
+	REQUIRE(utils::get_auth_method("digest_ie") == CURLAUTH_DIGEST_IE);
+	REQUIRE(utils::get_auth_method("gssnegotiate") == CURLAUTH_GSSNEGOTIATE);
+	REQUIRE(utils::get_auth_method("anysafe") == CURLAUTH_ANYSAFE);
+
+	REQUIRE(utils::get_auth_method("") == CURLAUTH_ANY);
+	REQUIRE(utils::get_auth_method("test") == CURLAUTH_ANY);
+}
+
+TEST_CASE(
+		"get_proxy_type() returns enumerated constant "
+		"on defined values and undefined values",
+		"[utils]")
+{
+	REQUIRE(utils::get_proxy_type("http") == CURLPROXY_HTTP);
+	REQUIRE(utils::get_proxy_type("socks4") == CURLPROXY_SOCKS4);
+	REQUIRE(utils::get_proxy_type("socks5") == CURLPROXY_SOCKS5);
+	REQUIRE(utils::get_proxy_type("socks5h") == CURLPROXY_SOCKS5_HOSTNAME);
+
+	REQUIRE(utils::get_proxy_type("") == CURLPROXY_HTTP);
+	REQUIRE(utils::get_proxy_type("test") == CURLPROXY_HTTP);
+}
+
+TEST_CASE("is_valid_attribute returns true if given string is an STFL attribute",
+		"[utils]")
+{
+	const std::vector<std::string> invalid = {
+		"foo",
+		"bar",
+		"baz",
+		"quux"
+	};
+	for (const auto& attr : invalid) {
+		REQUIRE_FALSE(utils::is_valid_attribute(attr));
+	}
+
+	const std::vector<std::string> valid = {
+		"standout",
+		"underline",
+		"reverse",
+		"blink",
+		"dim",
+		"bold",
+		"protect",
+		"invis",
+		"default"
+	};
+	for (const auto& attr : valid) {
+		REQUIRE(utils::is_valid_attribute(attr));
+	}
+}
+
+TEST_CASE("unescape_url() takes a percent-encoded string and returns the string "
+		"with a precent escaped string",
+		"[utils]")
+{
+	REQUIRE(utils::unescape_url("foo%20bar") == "foo bar");
+	REQUIRE(utils::unescape_url(
+			"%21%23%24%26%27%28%29%2A%2B%2C%2F%3A%3B%3D%3F%40%5B%5D") ==
+			"!#$&'()*+,/:;=?@[]");
+	REQUIRE(utils::unescape_url("%00") == "");
+
+}
